# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .named_scenario_input_chat_history_variable_value_request import NamedScenarioInputChatHistoryVariableValueRequest
from .named_scenario_input_string_variable_value_request import NamedScenarioInputStringVariableValueRequest


class NamedScenarioInputRequest_String(NamedScenarioInputStringVariableValueRequest):
    type: typing.Literal["STRING"] = "STRING"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class NamedScenarioInputRequest_ChatHistory(NamedScenarioInputChatHistoryVariableValueRequest):
    type: typing.Literal["CHAT_HISTORY"] = "CHAT_HISTORY"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


NamedScenarioInputRequest = typing.Union[NamedScenarioInputRequest_String, NamedScenarioInputRequest_ChatHistory]



# This file was auto-generated by Fern from our API Definition.

import pydantic

IS_PYDANTIC_V2 = pydantic.VERSION.startswith("2.")

if IS_PYDANTIC_V2:
    import pydantic.v1 as pydantic_v1  # type: ignore  # nopycln: import
else:
    import pydantic as pydantic_v1  # type: ignore  # nopycln: import

__all__ = ["pydantic_v1"]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .named_test_case_chat_history_variable_value import NamedTestCaseChatHistoryVariableValue
from .named_test_case_error_variable_value import NamedTestCaseErrorVariableValue
from .named_test_case_function_call_variable_value import NamedTestCaseFunctionCallVariableValue
from .named_test_case_json_variable_value import NamedTestCaseJsonVariableValue
from .named_test_case_number_variable_value import NamedTestCaseNumberVariableValue
from .named_test_case_search_results_variable_value import NamedTestCaseSearchResultsVariableValue
from .named_test_case_string_variable_value import NamedTestCaseStringVariableValue


class NamedTestCaseVariableValue_String(NamedTestCaseStringVariableValue):
    type: typing.Literal["STRING"] = "STRING"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class NamedTestCaseVariableValue_Number(NamedTestCaseNumberVariableValue):
    type: typing.Literal["NUMBER"] = "NUMBER"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class NamedTestCaseVariableValue_Json(NamedTestCaseJsonVariableValue):
    type: typing.Literal["JSON"] = "JSON"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class NamedTestCaseVariableValue_ChatHistory(NamedTestCaseChatHistoryVariableValue):
    type: typing.Literal["CHAT_HISTORY"] = "CHAT_HISTORY"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class NamedTestCaseVariableValue_SearchResults(NamedTestCaseSearchResultsVariableValue):
    type: typing.Literal["SEARCH_RESULTS"] = "SEARCH_RESULTS"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class NamedTestCaseVariableValue_Error(NamedTestCaseErrorVariableValue):
    type: typing.Literal["ERROR"] = "ERROR"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class NamedTestCaseVariableValue_FunctionCall(NamedTestCaseFunctionCallVariableValue):
    type: typing.Literal["FUNCTION_CALL"] = "FUNCTION_CALL"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


NamedTestCaseVariableValue = typing.Union[
    NamedTestCaseVariableValue_String,
    NamedTestCaseVariableValue_Number,
    NamedTestCaseVariableValue_Json,
    NamedTestCaseVariableValue_ChatHistory,
    NamedTestCaseVariableValue_SearchResults,
    NamedTestCaseVariableValue_Error,
    NamedTestCaseVariableValue_FunctionCall,
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .templating_node_array_result import TemplatingNodeArrayResult
from .templating_node_chat_history_result import TemplatingNodeChatHistoryResult
from .templating_node_error_result import TemplatingNodeErrorResult
from .templating_node_function_call_result import TemplatingNodeFunctionCallResult
from .templating_node_json_result import TemplatingNodeJsonResult
from .templating_node_number_result import TemplatingNodeNumberResult
from .templating_node_search_results_result import TemplatingNodeSearchResultsResult
from .templating_node_string_result import TemplatingNodeStringResult


class TemplatingNodeResultOutput_String(TemplatingNodeStringResult):
    type: typing.Literal["STRING"] = "STRING"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TemplatingNodeResultOutput_Number(TemplatingNodeNumberResult):
    type: typing.Literal["NUMBER"] = "NUMBER"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TemplatingNodeResultOutput_Json(TemplatingNodeJsonResult):
    type: typing.Literal["JSON"] = "JSON"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TemplatingNodeResultOutput_ChatHistory(TemplatingNodeChatHistoryResult):
    type: typing.Literal["CHAT_HISTORY"] = "CHAT_HISTORY"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TemplatingNodeResultOutput_SearchResults(TemplatingNodeSearchResultsResult):
    type: typing.Literal["SEARCH_RESULTS"] = "SEARCH_RESULTS"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TemplatingNodeResultOutput_Error(TemplatingNodeErrorResult):
    type: typing.Literal["ERROR"] = "ERROR"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TemplatingNodeResultOutput_Array(TemplatingNodeArrayResult):
    type: typing.Literal["ARRAY"] = "ARRAY"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TemplatingNodeResultOutput_FunctionCall(TemplatingNodeFunctionCallResult):
    type: typing.Literal["FUNCTION_CALL"] = "FUNCTION_CALL"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


TemplatingNodeResultOutput = typing.Union[
    TemplatingNodeResultOutput_String,
    TemplatingNodeResultOutput_Number,
    TemplatingNodeResultOutput_Json,
    TemplatingNodeResultOutput_ChatHistory,
    TemplatingNodeResultOutput_SearchResults,
    TemplatingNodeResultOutput_Error,
    TemplatingNodeResultOutput_Array,
    TemplatingNodeResultOutput_FunctionCall,
]



# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.jsonable_encoder import jsonable_encoder
from ...core.pydantic_utilities import pydantic_v1
from ...core.remove_none_from_dict import remove_none_from_dict
from ...core.request_options import RequestOptions
from ...types.paginated_slim_workflow_deployment_list import PaginatedSlimWorkflowDeploymentList
from ...types.workflow_deployment_read import WorkflowDeploymentRead
from .types.workflow_deployments_list_request_status import WorkflowDeploymentsListRequestStatus


class WorkflowDeploymentsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        *,
        limit: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        ordering: typing.Optional[str] = None,
        status: typing.Optional[WorkflowDeploymentsListRequestStatus] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PaginatedSlimWorkflowDeploymentList:
        """
        Parameters:
            - limit: typing.Optional[int]. Number of results to return per page.

            - offset: typing.Optional[int]. The initial index from which to return the results.

            - ordering: typing.Optional[str]. Which field to use when ordering the results.

            - status: typing.Optional[WorkflowDeploymentsListRequestStatus]. status

            - request_options: typing.Optional[RequestOptions]. Request-specific configuration.
        ---
        from vellum.client import Vellum

        client = Vellum(
            api_key="YOUR_API_KEY",
        )
        client.workflow_deployments.list()
        """
        _response = self._client_wrapper.httpx_client.request(
            method="GET",
            url=urllib.parse.urljoin(f"{self._client_wrapper.get_environment().default}/", "v1/workflow-deployments"),
            params=jsonable_encoder(
                remove_none_from_dict(
                    {
                        "limit": limit,
                        "offset": offset,
                        "ordering": ordering,
                        "status": status,
                        **(
                            request_options.get("additional_query_parameters", {})
                            if request_options is not None
                            else {}
                        ),
                    }
                )
            ),
            headers=jsonable_encoder(
                remove_none_from_dict(
                    {
                        **self._client_wrapper.get_headers(),
                        **(request_options.get("additional_headers", {}) if request_options is not None else {}),
                    }
                )
            ),
            timeout=request_options.get("timeout_in_seconds")
            if request_options is not None and request_options.get("timeout_in_seconds") is not None
            else self._client_wrapper.get_timeout(),
            retries=0,
            max_retries=request_options.get("max_retries") if request_options is not None else 0,  # type: ignore
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(PaginatedSlimWorkflowDeploymentList, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def retrieve(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> WorkflowDeploymentRead:
        """
        Used to retrieve a workflow deployment given its ID or name.

        Parameters:
            - id: str. Either the Workflow Deployment's ID or its unique name

            - request_options: typing.Optional[RequestOptions]. Request-specific configuration.
        ---
        from vellum.client import Vellum

        client = Vellum(
            api_key="YOUR_API_KEY",
        )
        client.workflow_deployments.retrieve(
            id="id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            method="GET",
            url=urllib.parse.urljoin(
                f"{self._client_wrapper.get_environment().default}/", f"v1/workflow-deployments/{jsonable_encoder(id)}"
            ),
            params=jsonable_encoder(
                request_options.get("additional_query_parameters") if request_options is not None else None
            ),
            headers=jsonable_encoder(
                remove_none_from_dict(
                    {
                        **self._client_wrapper.get_headers(),
                        **(request_options.get("additional_headers", {}) if request_options is not None else {}),
                    }
                )
            ),
            timeout=request_options.get("timeout_in_seconds")
            if request_options is not None and request_options.get("timeout_in_seconds") is not None
            else self._client_wrapper.get_timeout(),
            retries=0,
            max_retries=request_options.get("max_retries") if request_options is not None else 0,  # type: ignore
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(WorkflowDeploymentRead, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncWorkflowDeploymentsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        *,
        limit: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        ordering: typing.Optional[str] = None,
        status: typing.Optional[WorkflowDeploymentsListRequestStatus] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> PaginatedSlimWorkflowDeploymentList:
        """
        Parameters:
            - limit: typing.Optional[int]. Number of results to return per page.

            - offset: typing.Optional[int]. The initial index from which to return the results.

            - ordering: typing.Optional[str]. Which field to use when ordering the results.

            - status: typing.Optional[WorkflowDeploymentsListRequestStatus]. status

            - request_options: typing.Optional[RequestOptions]. Request-specific configuration.
        ---
        from vellum.client import AsyncVellum

        client = AsyncVellum(
            api_key="YOUR_API_KEY",
        )
        await client.workflow_deployments.list()
        """
        _response = await self._client_wrapper.httpx_client.request(
            method="GET",
            url=urllib.parse.urljoin(f"{self._client_wrapper.get_environment().default}/", "v1/workflow-deployments"),
            params=jsonable_encoder(
                remove_none_from_dict(
                    {
                        "limit": limit,
                        "offset": offset,
                        "ordering": ordering,
                        "status": status,
                        **(
                            request_options.get("additional_query_parameters", {})
                            if request_options is not None
                            else {}
                        ),
                    }
                )
            ),
            headers=jsonable_encoder(
                remove_none_from_dict(
                    {
                        **self._client_wrapper.get_headers(),
                        **(request_options.get("additional_headers", {}) if request_options is not None else {}),
                    }
                )
            ),
            timeout=request_options.get("timeout_in_seconds")
            if request_options is not None and request_options.get("timeout_in_seconds") is not None
            else self._client_wrapper.get_timeout(),
            retries=0,
            max_retries=request_options.get("max_retries") if request_options is not None else 0,  # type: ignore
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(PaginatedSlimWorkflowDeploymentList, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def retrieve(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> WorkflowDeploymentRead:
        """
        Used to retrieve a workflow deployment given its ID or name.

        Parameters:
            - id: str. Either the Workflow Deployment's ID or its unique name

            - request_options: typing.Optional[RequestOptions]. Request-specific configuration.
        ---
        from vellum.client import AsyncVellum

        client = AsyncVellum(
            api_key="YOUR_API_KEY",
        )
        await client.workflow_deployments.retrieve(
            id="id",
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            method="GET",
            url=urllib.parse.urljoin(
                f"{self._client_wrapper.get_environment().default}/", f"v1/workflow-deployments/{jsonable_encoder(id)}"
            ),
            params=jsonable_encoder(
                request_options.get("additional_query_parameters") if request_options is not None else None
            ),
            headers=jsonable_encoder(
                remove_none_from_dict(
                    {
                        **self._client_wrapper.get_headers(),
                        **(request_options.get("additional_headers", {}) if request_options is not None else {}),
                    }
                )
            ),
            timeout=request_options.get("timeout_in_seconds")
            if request_options is not None and request_options.get("timeout_in_seconds") is not None
            else self._client_wrapper.get_timeout(),
            retries=0,
            max_retries=request_options.get("max_retries") if request_options is not None else 0,  # type: ignore
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(WorkflowDeploymentRead, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .api_node_result import ApiNodeResult
from .code_execution_node_result import CodeExecutionNodeResult
from .conditional_node_result import ConditionalNodeResult
from .prompt_node_result import PromptNodeResult
from .search_node_result import SearchNodeResult
from .subworkflow_node_result import SubworkflowNodeResult
from .templating_node_result import TemplatingNodeResult
from .terminal_node_result import TerminalNodeResult


class WorkflowNodeResultData_Prompt(PromptNodeResult):
    type: typing.Literal["PROMPT"] = "PROMPT"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class WorkflowNodeResultData_Search(SearchNodeResult):
    type: typing.Literal["SEARCH"] = "SEARCH"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class WorkflowNodeResultData_Templating(TemplatingNodeResult):
    type: typing.Literal["TEMPLATING"] = "TEMPLATING"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class WorkflowNodeResultData_CodeExecution(CodeExecutionNodeResult):
    type: typing.Literal["CODE_EXECUTION"] = "CODE_EXECUTION"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class WorkflowNodeResultData_Conditional(ConditionalNodeResult):
    type: typing.Literal["CONDITIONAL"] = "CONDITIONAL"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class WorkflowNodeResultData_Api(ApiNodeResult):
    type: typing.Literal["API"] = "API"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class WorkflowNodeResultData_Terminal(TerminalNodeResult):
    type: typing.Literal["TERMINAL"] = "TERMINAL"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class WorkflowNodeResultData_Subworkflow(SubworkflowNodeResult):
    type: typing.Literal["SUBWORKFLOW"] = "SUBWORKFLOW"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


WorkflowNodeResultData = typing.Union[
    WorkflowNodeResultData_Prompt,
    WorkflowNodeResultData_Search,
    WorkflowNodeResultData_Templating,
    WorkflowNodeResultData_CodeExecution,
    WorkflowNodeResultData_Conditional,
    WorkflowNodeResultData_Api,
    WorkflowNodeResultData_Terminal,
    WorkflowNodeResultData_Subworkflow,
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .terminal_node_array_result import TerminalNodeArrayResult
from .terminal_node_chat_history_result import TerminalNodeChatHistoryResult
from .terminal_node_error_result import TerminalNodeErrorResult
from .terminal_node_function_call_result import TerminalNodeFunctionCallResult
from .terminal_node_json_result import TerminalNodeJsonResult
from .terminal_node_number_result import TerminalNodeNumberResult
from .terminal_node_search_results_result import TerminalNodeSearchResultsResult
from .terminal_node_string_result import TerminalNodeStringResult


class TerminalNodeResultOutput_String(TerminalNodeStringResult):
    type: typing.Literal["STRING"] = "STRING"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TerminalNodeResultOutput_Number(TerminalNodeNumberResult):
    type: typing.Literal["NUMBER"] = "NUMBER"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TerminalNodeResultOutput_Json(TerminalNodeJsonResult):
    type: typing.Literal["JSON"] = "JSON"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TerminalNodeResultOutput_ChatHistory(TerminalNodeChatHistoryResult):
    type: typing.Literal["CHAT_HISTORY"] = "CHAT_HISTORY"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TerminalNodeResultOutput_SearchResults(TerminalNodeSearchResultsResult):
    type: typing.Literal["SEARCH_RESULTS"] = "SEARCH_RESULTS"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TerminalNodeResultOutput_Array(TerminalNodeArrayResult):
    type: typing.Literal["ARRAY"] = "ARRAY"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TerminalNodeResultOutput_FunctionCall(TerminalNodeFunctionCallResult):
    type: typing.Literal["FUNCTION_CALL"] = "FUNCTION_CALL"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TerminalNodeResultOutput_Error(TerminalNodeErrorResult):
    type: typing.Literal["ERROR"] = "ERROR"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


TerminalNodeResultOutput = typing.Union[
    TerminalNodeResultOutput_String,
    TerminalNodeResultOutput_Number,
    TerminalNodeResultOutput_Json,
    TerminalNodeResultOutput_ChatHistory,
    TerminalNodeResultOutput_SearchResults,
    TerminalNodeResultOutput_Array,
    TerminalNodeResultOutput_FunctionCall,
    TerminalNodeResultOutput_Error,
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .function_call_chat_message_content import FunctionCallChatMessageContent
from .image_chat_message_content import ImageChatMessageContent
from .string_chat_message_content import StringChatMessageContent


class ArrayChatMessageContentItem_String(StringChatMessageContent):
    type: typing.Literal["STRING"] = "STRING"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class ArrayChatMessageContentItem_FunctionCall(FunctionCallChatMessageContent):
    type: typing.Literal["FUNCTION_CALL"] = "FUNCTION_CALL"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class ArrayChatMessageContentItem_Image(ImageChatMessageContent):
    type: typing.Literal["IMAGE"] = "IMAGE"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


ArrayChatMessageContentItem = typing.Union[
    ArrayChatMessageContentItem_String, ArrayChatMessageContentItem_FunctionCall, ArrayChatMessageContentItem_Image
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .function_call_chat_message_content_request import FunctionCallChatMessageContentRequest
from .image_chat_message_content_request import ImageChatMessageContentRequest
from .string_chat_message_content_request import StringChatMessageContentRequest


class ArrayChatMessageContentItemRequest_String(StringChatMessageContentRequest):
    type: typing.Literal["STRING"] = "STRING"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class ArrayChatMessageContentItemRequest_FunctionCall(FunctionCallChatMessageContentRequest):
    type: typing.Literal["FUNCTION_CALL"] = "FUNCTION_CALL"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class ArrayChatMessageContentItemRequest_Image(ImageChatMessageContentRequest):
    type: typing.Literal["IMAGE"] = "IMAGE"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


ArrayChatMessageContentItemRequest = typing.Union[
    ArrayChatMessageContentItemRequest_String,
    ArrayChatMessageContentItemRequest_FunctionCall,
    ArrayChatMessageContentItemRequest_Image,
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .test_suite_run_deployment_release_tag_exec_config_request import TestSuiteRunDeploymentReleaseTagExecConfigRequest
from .test_suite_run_external_exec_config_request import TestSuiteRunExternalExecConfigRequest
from .test_suite_run_workflow_release_tag_exec_config_request import TestSuiteRunWorkflowReleaseTagExecConfigRequest


class TestSuiteRunExecConfigRequest_DeploymentReleaseTag(TestSuiteRunDeploymentReleaseTagExecConfigRequest):
    type: typing.Literal["DEPLOYMENT_RELEASE_TAG"] = "DEPLOYMENT_RELEASE_TAG"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TestSuiteRunExecConfigRequest_WorkflowReleaseTag(TestSuiteRunWorkflowReleaseTagExecConfigRequest):
    type: typing.Literal["WORKFLOW_RELEASE_TAG"] = "WORKFLOW_RELEASE_TAG"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class TestSuiteRunExecConfigRequest_External(TestSuiteRunExternalExecConfigRequest):
    type: typing.Literal["EXTERNAL"] = "EXTERNAL"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


TestSuiteRunExecConfigRequest = typing.Union[
    TestSuiteRunExecConfigRequest_DeploymentReleaseTag,
    TestSuiteRunExecConfigRequest_WorkflowReleaseTag,
    TestSuiteRunExecConfigRequest_External,
]



'''
# `vellum_document_index`

Refer to the Terraform Registry for docs: [`vellum_document_index`](https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs/resources/document_index).
'''
from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

from .._jsii import *

import cdktf as _cdktf_9a9027ec
import constructs as _constructs_77d1e7e8


class DocumentIndex(
    _cdktf_9a9027ec.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="vellum-ai_vellum.documentIndex.DocumentIndex",
):
    '''Represents a {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs/resources/document_index vellum_document_index}.'''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        label: builtins.str,
        name: builtins.str,
        environment: typing.Optional[builtins.str] = None,
        status: typing.Optional[builtins.str] = None,
        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
        count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
    ) -> None:
        '''Create a new {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs/resources/document_index vellum_document_index} Resource.

        :param scope: The scope in which to define this construct.
        :param id: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param label: A human-readable label for the document index. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs/resources/document_index#label DocumentIndex#label}
        :param name: A name that uniquely identifies this index within its workspace. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs/resources/document_index#name DocumentIndex#name}
        :param environment: The environment this document index is used in. - ``DEVELOPMENT`` - Development - ``STAGING`` - Staging - ``PRODUCTION`` - Production Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs/resources/document_index#environment DocumentIndex#environment}
        :param status: The current status of the document index. - ``ACTIVE`` - Active - ``ARCHIVED`` - Archived Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs/resources/document_index#status DocumentIndex#status}
        :param connection: 
        :param count: 
        :param depends_on: 
        :param for_each: 
        :param lifecycle: 
        :param provider: 
        :param provisioners: 
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__0751847ca1b05a8752b6d12df3c1097c8ee7a048412870faf9e1bcb2ca1a4f19)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        config = DocumentIndexConfig(
            label=label,
            name=name,
            environment=environment,
            status=status,
            connection=connection,
            count=count,
            depends_on=depends_on,
            for_each=for_each,
            lifecycle=lifecycle,
            provider=provider,
            provisioners=provisioners,
        )

        jsii.create(self.__class__, self, [scope, id, config])

    @jsii.member(jsii_name="generateConfigForImport")
    @builtins.classmethod
    def generate_config_for_import(
        cls,
        scope: _constructs_77d1e7e8.Construct,
        import_to_id: builtins.str,
        import_from_id: builtins.str,
        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
    ) -> _cdktf_9a9027ec.ImportableResource:
        '''Generates CDKTF code for importing a DocumentIndex resource upon running "cdktf plan ".

        :param scope: The scope in which to define this construct.
        :param import_to_id: The construct id used in the generated config for the DocumentIndex to import.
        :param import_from_id: The id of the existing DocumentIndex that should be imported. Refer to the {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs/resources/document_index#import import section} in the documentation of this resource for the id to use
        :param provider: ? Optional instance of the provider where the DocumentIndex to import is found.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__dc48d775af9f151cb9ef4f2112a12fea79289a24be51d0cae2054249fbc7b7ec)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument import_to_id", value=import_to_id, expected_type=type_hints["import_to_id"])
            check_type(argname="argument import_from_id", value=import_from_id, expected_type=type_hints["import_from_id"])
            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
        return typing.cast(_cdktf_9a9027ec.ImportableResource, jsii.sinvoke(cls, "generateConfigForImport", [scope, import_to_id, import_from_id, provider]))

    @jsii.member(jsii_name="resetEnvironment")
    def reset_environment(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetEnvironment", []))

    @jsii.member(jsii_name="resetStatus")
    def reset_status(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetStatus", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.member(jsii_name="synthesizeHclAttributes")
    def _synthesize_hcl_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeHclAttributes", []))

    @jsii.python.classproperty
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property
    @jsii.member(jsii_name="created")
    def created(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "created"))

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "id"))

    @builtins.property
    @jsii.member(jsii_name="environmentInput")
    def environment_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "environmentInput"))

    @builtins.property
    @jsii.member(jsii_name="labelInput")
    def label_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "labelInput"))

    @builtins.property
    @jsii.member(jsii_name="nameInput")
    def name_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "nameInput"))

    @builtins.property
    @jsii.member(jsii_name="statusInput")
    def status_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "statusInput"))

    @builtins.property
    @jsii.member(jsii_name="environment")
    def environment(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "environment"))

    @environment.setter
    def environment(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bf57026eb472d19081b573c581c3a634226c3830ec5503e4250caeb2d3667f4a)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "environment", value)

    @builtins.property
    @jsii.member(jsii_name="label")
    def label(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "label"))

    @label.setter
    def label(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__afd1f32093dd34875f95059e21acf663b1f316fcf6f8322cf49b7a4f15572775)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "label", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "name"))

    @name.setter
    def name(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__b0dd98d80b775d4b66d0b03813c3883c7436d6ff207fe6df0f2c1ba0cbf4b467)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> builtins.str:
        return typing.cast(builtins.str, jsii.get(self, "status"))

    @status.setter
    def status(self, value: builtins.str) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__97df11ff01445aecc3848c3d22f8f43002dd2193bfa13d3973ac99da76831ec2)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "status", value)


@jsii.data_type(
    jsii_type="vellum-ai_vellum.documentIndex.DocumentIndexConfig",
    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
    name_mapping={
        "connection": "connection",
        "count": "count",
        "depends_on": "dependsOn",
        "for_each": "forEach",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "provisioners": "provisioners",
        "label": "label",
        "name": "name",
        "environment": "environment",
        "status": "status",
    },
)
class DocumentIndexConfig(_cdktf_9a9027ec.TerraformMetaArguments):
    def __init__(
        self,
        *,
        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
        count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
        label: builtins.str,
        name: builtins.str,
        environment: typing.Optional[builtins.str] = None,
        status: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param connection: 
        :param count: 
        :param depends_on: 
        :param for_each: 
        :param lifecycle: 
        :param provider: 
        :param provisioners: 
        :param label: A human-readable label for the document index. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs/resources/document_index#label DocumentIndex#label}
        :param name: A name that uniquely identifies this index within its workspace. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs/resources/document_index#name DocumentIndex#name}
        :param environment: The environment this document index is used in. - ``DEVELOPMENT`` - Development - ``STAGING`` - Staging - ``PRODUCTION`` - Production Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs/resources/document_index#environment DocumentIndex#environment}
        :param status: The current status of the document index. - ``ACTIVE`` - Active - ``ARCHIVED`` - Archived Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs/resources/document_index#status DocumentIndex#status}
        '''
        if isinstance(lifecycle, dict):
            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__119259bd47e6fe3a6870fdc08f5901ccfef95cae30a49c3268a665d319727301)
            check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
            check_type(argname="argument count", value=count, expected_type=type_hints["count"])
            check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
            check_type(argname="argument for_each", value=for_each, expected_type=type_hints["for_each"])
            check_type(argname="argument lifecycle", value=lifecycle, expected_type=type_hints["lifecycle"])
            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
            check_type(argname="argument provisioners", value=provisioners, expected_type=type_hints["provisioners"])
            check_type(argname="argument label", value=label, expected_type=type_hints["label"])
            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
            check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
            check_type(argname="argument status", value=status, expected_type=type_hints["status"])
        self._values: typing.Dict[builtins.str, typing.Any] = {
            "label": label,
            "name": name,
        }
        if connection is not None:
            self._values["connection"] = connection
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if for_each is not None:
            self._values["for_each"] = for_each
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if provisioners is not None:
            self._values["provisioners"] = provisioners
        if environment is not None:
            self._values["environment"] = environment
        if status is not None:
            self._values["status"] = status

    @builtins.property
    def connection(
        self,
    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("connection")
        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)

    @builtins.property
    def count(
        self,
    ) -> typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("count")
        return typing.cast(typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]], result)

    @builtins.property
    def depends_on(
        self,
    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("depends_on")
        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)

    @builtins.property
    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
        '''
        :stability: experimental
        '''
        result = self._values.get("for_each")
        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)

    @builtins.property
    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
        '''
        :stability: experimental
        '''
        result = self._values.get("lifecycle")
        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)

    @builtins.property
    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provider")
        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)

    @builtins.property
    def provisioners(
        self,
    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
        '''
        :stability: experimental
        '''
        result = self._values.get("provisioners")
        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)

    @builtins.property
    def label(self) -> builtins.str:
        '''A human-readable label for the document index.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs/resources/document_index#label DocumentIndex#label}
        '''
        result = self._values.get("label")
        assert result is not None, "Required property 'label' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def name(self) -> builtins.str:
        '''A name that uniquely identifies this index within its workspace.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs/resources/document_index#name DocumentIndex#name}
        '''
        result = self._values.get("name")
        assert result is not None, "Required property 'name' is missing"
        return typing.cast(builtins.str, result)

    @builtins.property
    def environment(self) -> typing.Optional[builtins.str]:
        '''The environment this document index is used in.

        - ``DEVELOPMENT`` - Development
        - ``STAGING`` - Staging
        - ``PRODUCTION`` - Production

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs/resources/document_index#environment DocumentIndex#environment}
        '''
        result = self._values.get("environment")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def status(self) -> typing.Optional[builtins.str]:
        '''The current status of the document index.

        - ``ACTIVE`` - Active
        - ``ARCHIVED`` - Archived

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs/resources/document_index#status DocumentIndex#status}
        '''
        result = self._values.get("status")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DocumentIndexConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "DocumentIndex",
    "DocumentIndexConfig",
]

publication.publish()

def _typecheckingstub__0751847ca1b05a8752b6d12df3c1097c8ee7a048412870faf9e1bcb2ca1a4f19(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    label: builtins.str,
    name: builtins.str,
    environment: typing.Optional[builtins.str] = None,
    status: typing.Optional[builtins.str] = None,
    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
    count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__dc48d775af9f151cb9ef4f2112a12fea79289a24be51d0cae2054249fbc7b7ec(
    scope: _constructs_77d1e7e8.Construct,
    import_to_id: builtins.str,
    import_from_id: builtins.str,
    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bf57026eb472d19081b573c581c3a634226c3830ec5503e4250caeb2d3667f4a(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__afd1f32093dd34875f95059e21acf663b1f316fcf6f8322cf49b7a4f15572775(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__b0dd98d80b775d4b66d0b03813c3883c7436d6ff207fe6df0f2c1ba0cbf4b467(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__97df11ff01445aecc3848c3d22f8f43002dd2193bfa13d3973ac99da76831ec2(
    value: builtins.str,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__119259bd47e6fe3a6870fdc08f5901ccfef95cae30a49c3268a665d319727301(
    *,
    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
    count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
    label: builtins.str,
    name: builtins.str,
    environment: typing.Optional[builtins.str] = None,
    status: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from ..core.pydantic_utilities import pydantic_v1


class WorkflowExecutionActualStringRequest(pydantic_v1.BaseModel):
    output_id: typing.Optional[str] = pydantic_v1.Field(default=None)
    """
    The Vellum-generated ID of a workflow output. Must provide either this or output_key. output_key is typically preferred.
    """

    output_key: typing.Optional[str] = pydantic_v1.Field(default=None)
    """
    The user-defined name of a workflow output. Must provide either this or output_id. Should correspond to the `Name` specified in a Final Output Node. Generally preferred over output_id.
    """

    quality: typing.Optional[float] = pydantic_v1.Field(default=None)
    """
    Optionally provide a decimal number between 0.0 and 1.0 (inclusive) representing the quality of the output. 0 is the worst, 1 is the best.
    """

    timestamp: typing.Optional[float] = pydantic_v1.Field(default=None)
    """
    Optionally provide the timestamp representing when this feedback was collected. Used for reporting purposes.
    """

    desired_output_value: typing.Optional[str] = pydantic_v1.Field(default=None)
    """
    Optionally provide the value that the output ideally should have been.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.jsonable_encoder import jsonable_encoder
from ...core.pydantic_utilities import pydantic_v1
from ...core.remove_none_from_dict import remove_none_from_dict
from ...core.request_options import RequestOptions
from ...types.named_scenario_input_request import NamedScenarioInputRequest
from ...types.sandbox_scenario import SandboxScenario

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class SandboxesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def upsert_sandbox_scenario(
        self,
        id: str,
        *,
        label: typing.Optional[str] = OMIT,
        inputs: typing.Sequence[NamedScenarioInputRequest],
        scenario_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SandboxScenario:
        """
        Upserts a new scenario for a sandbox, keying off of the optionally provided scenario id.

        If an id is provided and has a match, the scenario will be updated. If no id is provided or no match
        is found, a new scenario will be appended to the end.

        Note that a full replacement of the scenario is performed, so any fields not provided will be removed
        or overwritten with default values.

        Parameters:
            - id: str. A UUID string identifying this sandbox.

            - label: typing.Optional[str].

            - inputs: typing.Sequence[NamedScenarioInputRequest]. The inputs for the scenario

            - scenario_id: typing.Optional[str]. The id of the scenario to update. If none is provided, an id will be generated and a new scenario will be appended.

            - request_options: typing.Optional[RequestOptions]. Request-specific configuration.
        ---
        from vellum.client import Vellum

        client = Vellum(
            api_key="YOUR_API_KEY",
        )
        client.sandboxes.upsert_sandbox_scenario(
            id="id",
            label="Scenario 1",
            inputs=[],
        )
        """
        _request: typing.Dict[str, typing.Any] = {"inputs": inputs}
        if label is not OMIT:
            _request["label"] = label
        if scenario_id is not OMIT:
            _request["scenario_id"] = scenario_id
        _response = self._client_wrapper.httpx_client.request(
            method="POST",
            url=urllib.parse.urljoin(
                f"{self._client_wrapper.get_environment().default}/", f"v1/sandboxes/{jsonable_encoder(id)}/scenarios"
            ),
            params=jsonable_encoder(
                request_options.get("additional_query_parameters") if request_options is not None else None
            ),
            json=jsonable_encoder(_request)
            if request_options is None or request_options.get("additional_body_parameters") is None
            else {
                **jsonable_encoder(_request),
                **(jsonable_encoder(remove_none_from_dict(request_options.get("additional_body_parameters", {})))),
            },
            headers=jsonable_encoder(
                remove_none_from_dict(
                    {
                        **self._client_wrapper.get_headers(),
                        **(request_options.get("additional_headers", {}) if request_options is not None else {}),
                    }
                )
            ),
            timeout=request_options.get("timeout_in_seconds")
            if request_options is not None and request_options.get("timeout_in_seconds") is not None
            else self._client_wrapper.get_timeout(),
            retries=0,
            max_retries=request_options.get("max_retries") if request_options is not None else 0,  # type: ignore
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(SandboxScenario, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete_sandbox_scenario(
        self, id: str, scenario_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Deletes an existing scenario from a sandbox, keying off of the provided scenario id.

        Parameters:
            - id: str. A UUID string identifying this sandbox.

            - scenario_id: str. An id identifying the scenario that you'd like to delete

            - request_options: typing.Optional[RequestOptions]. Request-specific configuration.
        ---
        from vellum.client import Vellum

        client = Vellum(
            api_key="YOUR_API_KEY",
        )
        client.sandboxes.delete_sandbox_scenario(
            id="id",
            scenario_id="scenario_id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            method="DELETE",
            url=urllib.parse.urljoin(
                f"{self._client_wrapper.get_environment().default}/",
                f"v1/sandboxes/{jsonable_encoder(id)}/scenarios/{jsonable_encoder(scenario_id)}",
            ),
            params=jsonable_encoder(
                request_options.get("additional_query_parameters") if request_options is not None else None
            ),
            headers=jsonable_encoder(
                remove_none_from_dict(
                    {
                        **self._client_wrapper.get_headers(),
                        **(request_options.get("additional_headers", {}) if request_options is not None else {}),
                    }
                )
            ),
            timeout=request_options.get("timeout_in_seconds")
            if request_options is not None and request_options.get("timeout_in_seconds") is not None
            else self._client_wrapper.get_timeout(),
            retries=0,
            max_retries=request_options.get("max_retries") if request_options is not None else 0,  # type: ignore
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncSandboxesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def upsert_sandbox_scenario(
        self,
        id: str,
        *,
        label: typing.Optional[str] = OMIT,
        inputs: typing.Sequence[NamedScenarioInputRequest],
        scenario_id: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SandboxScenario:
        """
        Upserts a new scenario for a sandbox, keying off of the optionally provided scenario id.

        If an id is provided and has a match, the scenario will be updated. If no id is provided or no match
        is found, a new scenario will be appended to the end.

        Note that a full replacement of the scenario is performed, so any fields not provided will be removed
        or overwritten with default values.

        Parameters:
            - id: str. A UUID string identifying this sandbox.

            - label: typing.Optional[str].

            - inputs: typing.Sequence[NamedScenarioInputRequest]. The inputs for the scenario

            - scenario_id: typing.Optional[str]. The id of the scenario to update. If none is provided, an id will be generated and a new scenario will be appended.

            - request_options: typing.Optional[RequestOptions]. Request-specific configuration.
        ---
        from vellum.client import AsyncVellum

        client = AsyncVellum(
            api_key="YOUR_API_KEY",
        )
        await client.sandboxes.upsert_sandbox_scenario(
            id="id",
            label="Scenario 1",
            inputs=[],
        )
        """
        _request: typing.Dict[str, typing.Any] = {"inputs": inputs}
        if label is not OMIT:
            _request["label"] = label
        if scenario_id is not OMIT:
            _request["scenario_id"] = scenario_id
        _response = await self._client_wrapper.httpx_client.request(
            method="POST",
            url=urllib.parse.urljoin(
                f"{self._client_wrapper.get_environment().default}/", f"v1/sandboxes/{jsonable_encoder(id)}/scenarios"
            ),
            params=jsonable_encoder(
                request_options.get("additional_query_parameters") if request_options is not None else None
            ),
            json=jsonable_encoder(_request)
            if request_options is None or request_options.get("additional_body_parameters") is None
            else {
                **jsonable_encoder(_request),
                **(jsonable_encoder(remove_none_from_dict(request_options.get("additional_body_parameters", {})))),
            },
            headers=jsonable_encoder(
                remove_none_from_dict(
                    {
                        **self._client_wrapper.get_headers(),
                        **(request_options.get("additional_headers", {}) if request_options is not None else {}),
                    }
                )
            ),
            timeout=request_options.get("timeout_in_seconds")
            if request_options is not None and request_options.get("timeout_in_seconds") is not None
            else self._client_wrapper.get_timeout(),
            retries=0,
            max_retries=request_options.get("max_retries") if request_options is not None else 0,  # type: ignore
        )
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(SandboxScenario, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete_sandbox_scenario(
        self, id: str, scenario_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Deletes an existing scenario from a sandbox, keying off of the provided scenario id.

        Parameters:
            - id: str. A UUID string identifying this sandbox.

            - scenario_id: str. An id identifying the scenario that you'd like to delete

            - request_options: typing.Optional[RequestOptions]. Request-specific configuration.
        ---
        from vellum.client import AsyncVellum

        client = AsyncVellum(
            api_key="YOUR_API_KEY",
        )
        await client.sandboxes.delete_sandbox_scenario(
            id="id",
            scenario_id="scenario_id",
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            method="DELETE",
            url=urllib.parse.urljoin(
                f"{self._client_wrapper.get_environment().default}/",
                f"v1/sandboxes/{jsonable_encoder(id)}/scenarios/{jsonable_encoder(scenario_id)}",
            ),
            params=jsonable_encoder(
                request_options.get("additional_query_parameters") if request_options is not None else None
            ),
            headers=jsonable_encoder(
                remove_none_from_dict(
                    {
                        **self._client_wrapper.get_headers(),
                        **(request_options.get("additional_headers", {}) if request_options is not None else {}),
                    }
                )
            ),
            timeout=request_options.get("timeout_in_seconds")
            if request_options is not None and request_options.get("timeout_in_seconds") is not None
            else self._client_wrapper.get_timeout(),
            retries=0,
            max_retries=request_options.get("max_retries") if request_options is not None else 0,  # type: ignore
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

VellumErrorCodeEnum = typing.Union[
    typing.Literal["INVALID_REQUEST", "PROVIDER_ERROR", "INTERNAL_SERVER_ERROR", "USER_DEFINED_ERROR"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from ..core.pydantic_utilities import pydantic_v1
from .node_output_compiled_value import NodeOutputCompiledValue
from .workflow_node_result_data import WorkflowNodeResultData


class StreamingWorkflowNodeResultEvent(pydantic_v1.BaseModel):
    """
    An event that indicates that the node has execution is in progress.
    """

    id: str
    node_id: str
    node_result_id: str
    ts: typing.Optional[dt.datetime] = None
    data: typing.Optional[WorkflowNodeResultData] = None
    source_execution_id: typing.Optional[str] = None
    output: typing.Optional[NodeOutputCompiledValue] = None
    output_index: typing.Optional[int] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



'''
# `provider`

Refer to the Terraform Registry for docs: [`vellum`](https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs).
'''
from pkgutil import extend_path
__path__ = extend_path(__path__, __name__)

import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

from .._jsii import *

import cdktf as _cdktf_9a9027ec
import constructs as _constructs_77d1e7e8


class VellumProvider(
    _cdktf_9a9027ec.TerraformProvider,
    metaclass=jsii.JSIIMeta,
    jsii_type="vellum-ai_vellum.provider.VellumProvider",
):
    '''Represents a {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs vellum}.'''

    def __init__(
        self,
        scope: _constructs_77d1e7e8.Construct,
        id: builtins.str,
        *,
        alias: typing.Optional[builtins.str] = None,
        api_key: typing.Optional[builtins.str] = None,
    ) -> None:
        '''Create a new {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs vellum} Resource.

        :param scope: The scope in which to define this construct.
        :param id: The scoped construct ID. Must be unique amongst siblings in the same scope
        :param alias: Alias name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs#alias VellumProvider#alias}
        :param api_key: API Key to authenticate with the Vellum API. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs#api_key VellumProvider#api_key}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__8f332a1b6664893e57a3554abbbfd334296d68a0c02222521351772fec263177)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
        config = VellumProviderConfig(alias=alias, api_key=api_key)

        jsii.create(self.__class__, self, [scope, id, config])

    @jsii.member(jsii_name="generateConfigForImport")
    @builtins.classmethod
    def generate_config_for_import(
        cls,
        scope: _constructs_77d1e7e8.Construct,
        import_to_id: builtins.str,
        import_from_id: builtins.str,
        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
    ) -> _cdktf_9a9027ec.ImportableResource:
        '''Generates CDKTF code for importing a VellumProvider resource upon running "cdktf plan ".

        :param scope: The scope in which to define this construct.
        :param import_to_id: The construct id used in the generated config for the VellumProvider to import.
        :param import_from_id: The id of the existing VellumProvider that should be imported. Refer to the {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs#import import section} in the documentation of this resource for the id to use
        :param provider: ? Optional instance of the provider where the VellumProvider to import is found.
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__43f598a9f664a05d63c3b7644f2981a0397df03284b98ca077e6d7265f6aebcb)
            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
            check_type(argname="argument import_to_id", value=import_to_id, expected_type=type_hints["import_to_id"])
            check_type(argname="argument import_from_id", value=import_from_id, expected_type=type_hints["import_from_id"])
            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
        return typing.cast(_cdktf_9a9027ec.ImportableResource, jsii.sinvoke(cls, "generateConfigForImport", [scope, import_to_id, import_from_id, provider]))

    @jsii.member(jsii_name="resetAlias")
    def reset_alias(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetAlias", []))

    @jsii.member(jsii_name="resetApiKey")
    def reset_api_key(self) -> None:
        return typing.cast(None, jsii.invoke(self, "resetApiKey", []))

    @jsii.member(jsii_name="synthesizeAttributes")
    def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))

    @jsii.member(jsii_name="synthesizeHclAttributes")
    def _synthesize_hcl_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeHclAttributes", []))

    @jsii.python.classproperty
    @jsii.member(jsii_name="tfResourceType")
    def TF_RESOURCE_TYPE(cls) -> builtins.str:
        return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))

    @builtins.property
    @jsii.member(jsii_name="aliasInput")
    def alias_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "aliasInput"))

    @builtins.property
    @jsii.member(jsii_name="apiKeyInput")
    def api_key_input(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "apiKeyInput"))

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "alias"))

    @alias.setter
    def alias(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__15a78e7b117167a258d082de10d77ec8038e1f5fcc5ff5ef0caadbce4dec2c02)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "alias", value)

    @builtins.property
    @jsii.member(jsii_name="apiKey")
    def api_key(self) -> typing.Optional[builtins.str]:
        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "apiKey"))

    @api_key.setter
    def api_key(self, value: typing.Optional[builtins.str]) -> None:
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__402b9018cf60ba05eb9ab72153d7f52235bd10a5f5615a074a53880068a8779b)
            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
        jsii.set(self, "apiKey", value)


@jsii.data_type(
    jsii_type="vellum-ai_vellum.provider.VellumProviderConfig",
    jsii_struct_bases=[],
    name_mapping={"alias": "alias", "api_key": "apiKey"},
)
class VellumProviderConfig:
    def __init__(
        self,
        *,
        alias: typing.Optional[builtins.str] = None,
        api_key: typing.Optional[builtins.str] = None,
    ) -> None:
        '''
        :param alias: Alias name. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs#alias VellumProvider#alias}
        :param api_key: API Key to authenticate with the Vellum API. Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs#api_key VellumProvider#api_key}
        '''
        if __debug__:
            type_hints = typing.get_type_hints(_typecheckingstub__bb8c32f1d43f1344224f7a690abc6e2489c4dff67cb93921483ed2cc4b5410e1)
            check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
            check_type(argname="argument api_key", value=api_key, expected_type=type_hints["api_key"])
        self._values: typing.Dict[builtins.str, typing.Any] = {}
        if alias is not None:
            self._values["alias"] = alias
        if api_key is not None:
            self._values["api_key"] = api_key

    @builtins.property
    def alias(self) -> typing.Optional[builtins.str]:
        '''Alias name.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs#alias VellumProvider#alias}
        '''
        result = self._values.get("alias")
        return typing.cast(typing.Optional[builtins.str], result)

    @builtins.property
    def api_key(self) -> typing.Optional[builtins.str]:
        '''API Key to authenticate with the Vellum API.

        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/vellum-ai/vellum/0.0.2/docs#api_key VellumProvider#api_key}
        '''
        result = self._values.get("api_key")
        return typing.cast(typing.Optional[builtins.str], result)

    def __eq__(self, rhs: typing.Any) -> builtins.bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs: typing.Any) -> builtins.bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VellumProviderConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "VellumProvider",
    "VellumProviderConfig",
]

publication.publish()

def _typecheckingstub__8f332a1b6664893e57a3554abbbfd334296d68a0c02222521351772fec263177(
    scope: _constructs_77d1e7e8.Construct,
    id: builtins.str,
    *,
    alias: typing.Optional[builtins.str] = None,
    api_key: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__43f598a9f664a05d63c3b7644f2981a0397df03284b98ca077e6d7265f6aebcb(
    scope: _constructs_77d1e7e8.Construct,
    import_to_id: builtins.str,
    import_from_id: builtins.str,
    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__15a78e7b117167a258d082de10d77ec8038e1f5fcc5ff5ef0caadbce4dec2c02(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__402b9018cf60ba05eb9ab72153d7f52235bd10a5f5615a074a53880068a8779b(
    value: typing.Optional[builtins.str],
) -> None:
    """Type checking stubs"""
    pass

def _typecheckingstub__bb8c32f1d43f1344224f7a690abc6e2489c4dff67cb93921483ed2cc4b5410e1(
    *,
    alias: typing.Optional[builtins.str] = None,
    api_key: typing.Optional[builtins.str] = None,
) -> None:
    """Type checking stubs"""
    pass



# This file was auto-generated by Fern from our API Definition.

from .workflow_deployments_list_request_status import WorkflowDeploymentsListRequestStatus

__all__ = ["WorkflowDeploymentsListRequestStatus"]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from ..core.pydantic_utilities import pydantic_v1


class SubmitCompletionActualRequest(pydantic_v1.BaseModel):
    id: typing.Optional[str] = pydantic_v1.Field(default=None)
    """
    The Vellum-generated ID of a previously generated completion. Must provide either this or external_id.
    """

    external_id: typing.Optional[str] = pydantic_v1.Field(default=None)
    """
    The external ID that was originally provided when generating the completion that you'd now like to submit actuals for. Must provide either this or id.
    """

    text: typing.Optional[str] = pydantic_v1.Field(default=None)
    """
    Text representing what the completion _should_ have been.
    """

    quality: typing.Optional[float] = pydantic_v1.Field(default=None)
    """
    A number between 0 and 1 representing the quality of the completion. 0 is the worst, 1 is the best.
    """

    timestamp: typing.Optional[dt.datetime] = pydantic_v1.Field(default=None)
    """
    Optionally provide the timestamp representing when this feedback was collected. Used for reporting purposes.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from ..core.pydantic_utilities import pydantic_v1
from .entity_status import EntityStatus
from .environment_enum import EnvironmentEnum
from .vellum_variable import VellumVariable


class DeploymentRead(pydantic_v1.BaseModel):
    id: str
    created: dt.datetime
    label: str = pydantic_v1.Field()
    """
    A human-readable label for the deployment
    """

    name: str = pydantic_v1.Field()
    """
    A name that uniquely identifies this deployment within its workspace
    """

    status: typing.Optional[EntityStatus] = pydantic_v1.Field(default=None)
    """
    The current status of the deployment
    
    - `ACTIVE` - Active
    - `ARCHIVED` - Archived
    """

    environment: typing.Optional[EnvironmentEnum] = pydantic_v1.Field(default=None)
    """
    The environment this deployment is used in
    
    - `DEVELOPMENT` - Development
    - `STAGING` - Staging
    - `PRODUCTION` - Production
    """

    last_deployed_on: dt.datetime
    input_variables: typing.List[VellumVariable]
    active_model_version_ids: typing.List[str] = pydantic_v1.Field()
    """
    Deprecated. The Prompt execution endpoints return a `prompt_version_id` that could be used instead.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .fulfilled_execute_workflow_workflow_result_event import FulfilledExecuteWorkflowWorkflowResultEvent
from .rejected_execute_workflow_workflow_result_event import RejectedExecuteWorkflowWorkflowResultEvent


class ExecuteWorkflowWorkflowResultEvent_Fulfilled(FulfilledExecuteWorkflowWorkflowResultEvent):
    state: typing.Literal["FULFILLED"] = "FULFILLED"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class ExecuteWorkflowWorkflowResultEvent_Rejected(RejectedExecuteWorkflowWorkflowResultEvent):
    state: typing.Literal["REJECTED"] = "REJECTED"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


ExecuteWorkflowWorkflowResultEvent = typing.Union[
    ExecuteWorkflowWorkflowResultEvent_Fulfilled, ExecuteWorkflowWorkflowResultEvent_Rejected
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .fulfilled_function_call import FulfilledFunctionCall
from .rejected_function_call import RejectedFunctionCall


class FunctionCall_Fulfilled(FulfilledFunctionCall):
    state: typing.Literal["FULFILLED"] = "FULFILLED"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class FunctionCall_Rejected(RejectedFunctionCall):
    state: typing.Literal["REJECTED"] = "REJECTED"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


FunctionCall = typing.Union[FunctionCall_Fulfilled, FunctionCall_Rejected]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .fulfilled_execute_prompt_response import FulfilledExecutePromptResponse
from .rejected_execute_prompt_response import RejectedExecutePromptResponse


class ExecutePromptResponse_Fulfilled(FulfilledExecutePromptResponse):
    state: typing.Literal["FULFILLED"] = "FULFILLED"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class ExecutePromptResponse_Rejected(RejectedExecutePromptResponse):
    state: typing.Literal["REJECTED"] = "REJECTED"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


ExecutePromptResponse = typing.Union[ExecutePromptResponse_Fulfilled, ExecutePromptResponse_Rejected]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from ..core.pydantic_utilities import pydantic_v1
from .search_filters_request import SearchFiltersRequest
from .search_result_merging_request import SearchResultMergingRequest
from .search_weights_request import SearchWeightsRequest


class SearchRequestOptionsRequest(pydantic_v1.BaseModel):
    limit: typing.Optional[int] = pydantic_v1.Field(default=None)
    """
    The maximum number of results to return.
    """

    weights: typing.Optional[SearchWeightsRequest] = pydantic_v1.Field(default=None)
    """
    The weights to use for the search. Must add up to 1.0.
    """

    result_merging: typing.Optional[SearchResultMergingRequest] = pydantic_v1.Field(default=None)
    """
    The configuration for merging results.
    """

    filters: typing.Optional[SearchFiltersRequest] = pydantic_v1.Field(default=None)
    """
    The filters to apply to the search.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

from .execution_array_vellum_value import ExecutionArrayVellumValue
from .execution_chat_history_vellum_value import ExecutionChatHistoryVellumValue
from .execution_error_vellum_value import ExecutionErrorVellumValue
from .execution_function_call_vellum_value import ExecutionFunctionCallVellumValue
from .execution_json_vellum_value import ExecutionJsonVellumValue
from .execution_number_vellum_value import ExecutionNumberVellumValue
from .execution_search_results_vellum_value import ExecutionSearchResultsVellumValue
from .execution_string_vellum_value import ExecutionStringVellumValue


class ExecutionVellumValue_String(ExecutionStringVellumValue):
    type: typing.Literal["STRING"] = "STRING"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class ExecutionVellumValue_Number(ExecutionNumberVellumValue):
    type: typing.Literal["NUMBER"] = "NUMBER"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class ExecutionVellumValue_Json(ExecutionJsonVellumValue):
    type: typing.Literal["JSON"] = "JSON"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class ExecutionVellumValue_ChatHistory(ExecutionChatHistoryVellumValue):
    type: typing.Literal["CHAT_HISTORY"] = "CHAT_HISTORY"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class ExecutionVellumValue_SearchResults(ExecutionSearchResultsVellumValue):
    type: typing.Literal["SEARCH_RESULTS"] = "SEARCH_RESULTS"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class ExecutionVellumValue_Error(ExecutionErrorVellumValue):
    type: typing.Literal["ERROR"] = "ERROR"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class ExecutionVellumValue_Array(ExecutionArrayVellumValue):
    type: typing.Literal["ARRAY"] = "ARRAY"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


class ExecutionVellumValue_FunctionCall(ExecutionFunctionCallVellumValue):
    type: typing.Literal["FUNCTION_CALL"] = "FUNCTION_CALL"

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True


ExecutionVellumValue = typing.Union[
    ExecutionVellumValue_String,
    ExecutionVellumValue_Number,
    ExecutionVellumValue_Json,
    ExecutionVellumValue_ChatHistory,
    ExecutionVellumValue_SearchResults,
    ExecutionVellumValue_Error,
    ExecutionVellumValue_Array,
    ExecutionVellumValue_FunctionCall,
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from ..core.pydantic_utilities import pydantic_v1


class ScenarioInputStringVariableValue(pydantic_v1.BaseModel):
    """
    Prompt Sandbox Scenario input value that is of type STRING
    """

    value: typing.Optional[str] = None
    input_variable_id: str

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic_v1.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from .api_node_result import ApiNodeResult
from .api_node_result_data import ApiNodeResultData
from .array_chat_message_content import ArrayChatMessageContent
from .array_chat_message_content_item import (
    ArrayChatMessageContentItem,
    ArrayChatMessageContentItem_FunctionCall,
    ArrayChatMessageContentItem_Image,
    ArrayChatMessageContentItem_String,
)
from .array_chat_message_content_item_request import (
    ArrayChatMessageContentItemRequest,
    ArrayChatMessageContentItemRequest_FunctionCall,
    ArrayChatMessageContentItemRequest_Image,
    ArrayChatMessageContentItemRequest_String,
)
from .array_chat_message_content_request import ArrayChatMessageContentRequest
from .array_enum import ArrayEnum
from .array_variable_value_item import (
    ArrayVariableValueItem,
    ArrayVariableValueItem_ChatHistory,
    ArrayVariableValueItem_Error,
    ArrayVariableValueItem_FunctionCall,
    ArrayVariableValueItem_Image,
    ArrayVariableValueItem_Json,
    ArrayVariableValueItem_Number,
    ArrayVariableValueItem_SearchResults,
    ArrayVariableValueItem_String,
)
from .chat_history_enum import ChatHistoryEnum
from .chat_history_input_request import ChatHistoryInputRequest
from .chat_history_variable_value import ChatHistoryVariableValue
from .chat_message import ChatMessage
from .chat_message_content import (
    ChatMessageContent,
    ChatMessageContent_Array,
    ChatMessageContent_FunctionCall,
    ChatMessageContent_Image,
    ChatMessageContent_String,
)
from .chat_message_content_request import (
    ChatMessageContentRequest,
    ChatMessageContentRequest_Array,
    ChatMessageContentRequest_FunctionCall,
    ChatMessageContentRequest_Image,
    ChatMessageContentRequest_String,
)
from .chat_message_request import ChatMessageRequest
from .chat_message_role import ChatMessageRole
from .code_execution_node_array_result import CodeExecutionNodeArrayResult
from .code_execution_node_chat_history_result import CodeExecutionNodeChatHistoryResult
from .code_execution_node_error_result import CodeExecutionNodeErrorResult
from .code_execution_node_function_call_result import CodeExecutionNodeFunctionCallResult
from .code_execution_node_json_result import CodeExecutionNodeJsonResult
from .code_execution_node_number_result import CodeExecutionNodeNumberResult
from .code_execution_node_result import CodeExecutionNodeResult
from .code_execution_node_result_data import CodeExecutionNodeResultData
from .code_execution_node_result_output import (
    CodeExecutionNodeResultOutput,
    CodeExecutionNodeResultOutput_Array,
    CodeExecutionNodeResultOutput_ChatHistory,
    CodeExecutionNodeResultOutput_Error,
    CodeExecutionNodeResultOutput_FunctionCall,
    CodeExecutionNodeResultOutput_Json,
    CodeExecutionNodeResultOutput_Number,
    CodeExecutionNodeResultOutput_SearchResults,
    CodeExecutionNodeResultOutput_String,
)
from .code_execution_node_search_results_result import CodeExecutionNodeSearchResultsResult
from .code_execution_node_string_result import CodeExecutionNodeStringResult
from .conditional_node_result import ConditionalNodeResult
from .conditional_node_result_data import ConditionalNodeResultData
from .deployment_provider_payload_response import DeploymentProviderPayloadResponse
from .deployment_read import DeploymentRead
from .document_document_to_document_index import DocumentDocumentToDocumentIndex
from .document_index_read import DocumentIndexRead
from .document_read import DocumentRead
from .document_status import DocumentStatus
from .enriched_normalized_completion import EnrichedNormalizedCompletion
from .entity_status import EntityStatus
from .environment_enum import EnvironmentEnum
from .error_enum import ErrorEnum
from .error_variable_value import ErrorVariableValue
from .error_vellum_value import ErrorVellumValue
from .execute_prompt_api_error_response import ExecutePromptApiErrorResponse
from .execute_prompt_event import (
    ExecutePromptEvent,
    ExecutePromptEvent_Fulfilled,
    ExecutePromptEvent_Initiated,
    ExecutePromptEvent_Rejected,
    ExecutePromptEvent_Streaming,
)
from .execute_prompt_response import (
    ExecutePromptResponse,
    ExecutePromptResponse_Fulfilled,
    ExecutePromptResponse_Rejected,
)
from .execute_workflow_error_response import ExecuteWorkflowErrorResponse
from .execute_workflow_response import ExecuteWorkflowResponse
from .execute_workflow_stream_error_response import ExecuteWorkflowStreamErrorResponse
from .execute_workflow_workflow_result_event import (
    ExecuteWorkflowWorkflowResultEvent,
    ExecuteWorkflowWorkflowResultEvent_Fulfilled,
    ExecuteWorkflowWorkflowResultEvent_Rejected,
)
from .execution_array_vellum_value import ExecutionArrayVellumValue
from .execution_chat_history_vellum_value import ExecutionChatHistoryVellumValue
from .execution_error_vellum_value import ExecutionErrorVellumValue
from .execution_function_call_vellum_value import ExecutionFunctionCallVellumValue
from .execution_json_vellum_value import ExecutionJsonVellumValue
from .execution_number_vellum_value import ExecutionNumberVellumValue
from .execution_search_results_vellum_value import ExecutionSearchResultsVellumValue
from .execution_string_vellum_value import ExecutionStringVellumValue
from .execution_vellum_value import (
    ExecutionVellumValue,
    ExecutionVellumValue_Array,
    ExecutionVellumValue_ChatHistory,
    ExecutionVellumValue_Error,
    ExecutionVellumValue_FunctionCall,
    ExecutionVellumValue_Json,
    ExecutionVellumValue_Number,
    ExecutionVellumValue_SearchResults,
    ExecutionVellumValue_String,
)
from .external_test_case_execution import ExternalTestCaseExecution
from .external_test_case_execution_request import ExternalTestCaseExecutionRequest
from .finish_reason_enum import FinishReasonEnum
from .fulfilled_enum import FulfilledEnum
from .fulfilled_execute_prompt_event import FulfilledExecutePromptEvent
from .fulfilled_execute_prompt_response import FulfilledExecutePromptResponse
from .fulfilled_execute_workflow_workflow_result_event import FulfilledExecuteWorkflowWorkflowResultEvent
from .fulfilled_function_call import FulfilledFunctionCall
from .fulfilled_function_call_request import FulfilledFunctionCallRequest
from .fulfilled_prompt_execution_meta import FulfilledPromptExecutionMeta
from .fulfilled_workflow_node_result_event import FulfilledWorkflowNodeResultEvent
from .function_call import FunctionCall, FunctionCall_Fulfilled, FunctionCall_Rejected
from .function_call_chat_message_content import FunctionCallChatMessageContent
from .function_call_chat_message_content_request import FunctionCallChatMessageContentRequest
from .function_call_chat_message_content_value import FunctionCallChatMessageContentValue
from .function_call_chat_message_content_value_request import FunctionCallChatMessageContentValueRequest
from .function_call_enum import FunctionCallEnum
from .function_call_variable_value import FunctionCallVariableValue
from .function_call_vellum_value import FunctionCallVellumValue
from .generate_error_response import GenerateErrorResponse
from .generate_options_request import GenerateOptionsRequest
from .generate_request import GenerateRequest
from .generate_response import GenerateResponse
from .generate_result import GenerateResult
from .generate_result_data import GenerateResultData
from .generate_result_error import GenerateResultError
from .generate_stream_response import GenerateStreamResponse
from .generate_stream_result import GenerateStreamResult
from .generate_stream_result_data import GenerateStreamResultData
from .image_chat_message_content import ImageChatMessageContent
from .image_chat_message_content_request import ImageChatMessageContentRequest
from .image_enum import ImageEnum
from .image_variable_value import ImageVariableValue
from .indexing_state_enum import IndexingStateEnum
from .initiated_enum import InitiatedEnum
from .initiated_execute_prompt_event import InitiatedExecutePromptEvent
from .initiated_prompt_execution_meta import InitiatedPromptExecutionMeta
from .initiated_workflow_node_result_event import InitiatedWorkflowNodeResultEvent
from .json_enum import JsonEnum
from .json_input_request import JsonInputRequest
from .json_variable_value import JsonVariableValue
from .json_vellum_value import JsonVellumValue
from .logical_operator import LogicalOperator
from .logprobs_enum import LogprobsEnum
from .metadata_filter_config_request import MetadataFilterConfigRequest
from .metadata_filter_rule_combinator import MetadataFilterRuleCombinator
from .metadata_filter_rule_request import MetadataFilterRuleRequest
from .ml_model_usage import MlModelUsage
from .named_scenario_input_chat_history_variable_value_request import NamedScenarioInputChatHistoryVariableValueRequest
from .named_scenario_input_request import (
    NamedScenarioInputRequest,
    NamedScenarioInputRequest_ChatHistory,
    NamedScenarioInputRequest_String,
)
from .named_scenario_input_string_variable_value_request import NamedScenarioInputStringVariableValueRequest
from .named_test_case_chat_history_variable_value import NamedTestCaseChatHistoryVariableValue
from .named_test_case_chat_history_variable_value_request import NamedTestCaseChatHistoryVariableValueRequest
from .named_test_case_error_variable_value import NamedTestCaseErrorVariableValue
from .named_test_case_error_variable_value_request import NamedTestCaseErrorVariableValueRequest
from .named_test_case_function_call_variable_value import NamedTestCaseFunctionCallVariableValue
from .named_test_case_function_call_variable_value_request import NamedTestCaseFunctionCallVariableValueRequest
from .named_test_case_json_variable_value import NamedTestCaseJsonVariableValue
from .named_test_case_json_variable_value_request import NamedTestCaseJsonVariableValueRequest
from .named_test_case_number_variable_value import NamedTestCaseNumberVariableValue
from .named_test_case_number_variable_value_request import NamedTestCaseNumberVariableValueRequest
from .named_test_case_search_results_variable_value import NamedTestCaseSearchResultsVariableValue
from .named_test_case_search_results_variable_value_request import NamedTestCaseSearchResultsVariableValueRequest
from .named_test_case_string_variable_value import NamedTestCaseStringVariableValue
from .named_test_case_string_variable_value_request import NamedTestCaseStringVariableValueRequest
from .named_test_case_variable_value import (
    NamedTestCaseVariableValue,
    NamedTestCaseVariableValue_ChatHistory,
    NamedTestCaseVariableValue_Error,
    NamedTestCaseVariableValue_FunctionCall,
    NamedTestCaseVariableValue_Json,
    NamedTestCaseVariableValue_Number,
    NamedTestCaseVariableValue_SearchResults,
    NamedTestCaseVariableValue_String,
)
from .named_test_case_variable_value_request import (
    NamedTestCaseVariableValueRequest,
    NamedTestCaseVariableValueRequest_ChatHistory,
    NamedTestCaseVariableValueRequest_Error,
    NamedTestCaseVariableValueRequest_FunctionCall,
    NamedTestCaseVariableValueRequest_Json,
    NamedTestCaseVariableValueRequest_Number,
    NamedTestCaseVariableValueRequest_SearchResults,
    NamedTestCaseVariableValueRequest_String,
)
from .node_input_compiled_array_value import NodeInputCompiledArrayValue
from .node_input_compiled_chat_history_value import NodeInputCompiledChatHistoryValue
from .node_input_compiled_error_value import NodeInputCompiledErrorValue
from .node_input_compiled_function_call import NodeInputCompiledFunctionCall
from .node_input_compiled_json_value import NodeInputCompiledJsonValue
from .node_input_compiled_number_value import NodeInputCompiledNumberValue
from .node_input_compiled_search_results_value import NodeInputCompiledSearchResultsValue
from .node_input_compiled_string_value import NodeInputCompiledStringValue
from .node_input_variable_compiled_value import (
    NodeInputVariableCompiledValue,
    NodeInputVariableCompiledValue_Array,
    NodeInputVariableCompiledValue_ChatHistory,
    NodeInputVariableCompiledValue_Error,
    NodeInputVariableCompiledValue_FunctionCall,
    NodeInputVariableCompiledValue_Json,
    NodeInputVariableCompiledValue_Number,
    NodeInputVariableCompiledValue_SearchResults,
    NodeInputVariableCompiledValue_String,
)
from .node_output_compiled_array_value import NodeOutputCompiledArrayValue
from .node_output_compiled_chat_history_value import NodeOutputCompiledChatHistoryValue
from .node_output_compiled_error_value import NodeOutputCompiledErrorValue
from .node_output_compiled_function_call_value import NodeOutputCompiledFunctionCallValue
from .node_output_compiled_json_value import NodeOutputCompiledJsonValue
from .node_output_compiled_number_value import NodeOutputCompiledNumberValue
from .node_output_compiled_search_results_value import NodeOutputCompiledSearchResultsValue
from .node_output_compiled_string_value import NodeOutputCompiledStringValue
from .node_output_compiled_value import (
    NodeOutputCompiledValue,
    NodeOutputCompiledValue_Array,
    NodeOutputCompiledValue_ChatHistory,
    NodeOutputCompiledValue_Error,
    NodeOutputCompiledValue_FunctionCall,
    NodeOutputCompiledValue_Json,
    NodeOutputCompiledValue_Number,
    NodeOutputCompiledValue_SearchResults,
    NodeOutputCompiledValue_String,
)
from .normalized_log_probs import NormalizedLogProbs
from .normalized_token_log_probs import NormalizedTokenLogProbs
from .number_enum import NumberEnum
from .number_variable_value import NumberVariableValue
from .paginated_document_index_read_list import PaginatedDocumentIndexReadList
from .paginated_slim_deployment_read_list import PaginatedSlimDeploymentReadList
from .paginated_slim_document_list import PaginatedSlimDocumentList
from .paginated_slim_workflow_deployment_list import PaginatedSlimWorkflowDeploymentList
from .paginated_test_suite_run_execution_list import PaginatedTestSuiteRunExecutionList
from .paginated_test_suite_test_case_list import PaginatedTestSuiteTestCaseList
from .processing_failure_reason_enum import ProcessingFailureReasonEnum
from .processing_state_enum import ProcessingStateEnum
from .prompt_deployment_expand_meta_request_request import PromptDeploymentExpandMetaRequestRequest
from .prompt_deployment_input_request import (
    PromptDeploymentInputRequest,
    PromptDeploymentInputRequest_ChatHistory,
    PromptDeploymentInputRequest_Json,
    PromptDeploymentInputRequest_String,
)
from .prompt_execution_meta import PromptExecutionMeta
from .prompt_node_result import PromptNodeResult
from .prompt_node_result_data import PromptNodeResultData
from .prompt_output import (
    PromptOutput,
    PromptOutput_Error,
    PromptOutput_FunctionCall,
    PromptOutput_Json,
    PromptOutput_String,
)
from .raw_prompt_execution_overrides_request import RawPromptExecutionOverridesRequest
from .rejected_enum import RejectedEnum
from .rejected_execute_prompt_event import RejectedExecutePromptEvent
from .rejected_execute_prompt_response import RejectedExecutePromptResponse
from .rejected_execute_workflow_workflow_result_event import RejectedExecuteWorkflowWorkflowResultEvent
from .rejected_function_call import RejectedFunctionCall
from .rejected_prompt_execution_meta import RejectedPromptExecutionMeta
from .rejected_workflow_node_result_event import RejectedWorkflowNodeResultEvent
from .sandbox_scenario import SandboxScenario
from .scenario_input import ScenarioInput, ScenarioInput_ChatHistory, ScenarioInput_String
from .scenario_input_chat_history_variable_value import ScenarioInputChatHistoryVariableValue
from .scenario_input_string_variable_value import ScenarioInputStringVariableValue
from .search_error_response import SearchErrorResponse
from .search_filters_request import SearchFiltersRequest
from .search_node_result import SearchNodeResult
from .search_node_result_data import SearchNodeResultData
from .search_request_options_request import SearchRequestOptionsRequest
from .search_response import SearchResponse
from .search_result import SearchResult
from .search_result_document import SearchResultDocument
from .search_result_document_request import SearchResultDocumentRequest
from .search_result_merging_request import SearchResultMergingRequest
from .search_result_request import SearchResultRequest
from .search_results_enum import SearchResultsEnum
from .search_results_variable_value import SearchResultsVariableValue
from .search_weights_request import SearchWeightsRequest
from .slim_deployment_read import SlimDeploymentRead
from .slim_document import SlimDocument
from .slim_workflow_deployment import SlimWorkflowDeployment
from .streaming_enum import StreamingEnum
from .streaming_execute_prompt_event import StreamingExecutePromptEvent
from .streaming_prompt_execution_meta import StreamingPromptExecutionMeta
from .streaming_workflow_node_result_event import StreamingWorkflowNodeResultEvent
from .string_chat_message_content import StringChatMessageContent
from .string_chat_message_content_request import StringChatMessageContentRequest
from .string_enum import StringEnum
from .string_input_request import StringInputRequest
from .string_variable_value import StringVariableValue
from .string_vellum_value import StringVellumValue
from .submit_completion_actual_request import SubmitCompletionActualRequest
from .submit_completion_actuals_error_response import SubmitCompletionActualsErrorResponse
from .submit_workflow_execution_actual_request import (
    SubmitWorkflowExecutionActualRequest,
    SubmitWorkflowExecutionActualRequest_ChatHistory,
    SubmitWorkflowExecutionActualRequest_Json,
    SubmitWorkflowExecutionActualRequest_String,
)
from .subworkflow_enum import SubworkflowEnum
from .subworkflow_node_result import SubworkflowNodeResult
from .templating_node_array_result import TemplatingNodeArrayResult
from .templating_node_chat_history_result import TemplatingNodeChatHistoryResult
from .templating_node_error_result import TemplatingNodeErrorResult
from .templating_node_function_call_result import TemplatingNodeFunctionCallResult
from .templating_node_json_result import TemplatingNodeJsonResult
from .templating_node_number_result import TemplatingNodeNumberResult
from .templating_node_result import TemplatingNodeResult
from .templating_node_result_data import TemplatingNodeResultData
from .templating_node_result_output import (
    TemplatingNodeResultOutput,
    TemplatingNodeResultOutput_Array,
    TemplatingNodeResultOutput_ChatHistory,
    TemplatingNodeResultOutput_Error,
    TemplatingNodeResultOutput_FunctionCall,
    TemplatingNodeResultOutput_Json,
    TemplatingNodeResultOutput_Number,
    TemplatingNodeResultOutput_SearchResults,
    TemplatingNodeResultOutput_String,
)
from .templating_node_search_results_result import TemplatingNodeSearchResultsResult
from .templating_node_string_result import TemplatingNodeStringResult
from .terminal_node_array_result import TerminalNodeArrayResult
from .terminal_node_chat_history_result import TerminalNodeChatHistoryResult
from .terminal_node_error_result import TerminalNodeErrorResult
from .terminal_node_function_call_result import TerminalNodeFunctionCallResult
from .terminal_node_json_result import TerminalNodeJsonResult
from .terminal_node_number_result import TerminalNodeNumberResult
from .terminal_node_result import TerminalNodeResult
from .terminal_node_result_data import TerminalNodeResultData
from .terminal_node_result_output import (
    TerminalNodeResultOutput,
    TerminalNodeResultOutput_Array,
    TerminalNodeResultOutput_ChatHistory,
    TerminalNodeResultOutput_Error,
    TerminalNodeResultOutput_FunctionCall,
    TerminalNodeResultOutput_Json,
    TerminalNodeResultOutput_Number,
    TerminalNodeResultOutput_SearchResults,
    TerminalNodeResultOutput_String,
)
from .terminal_node_search_results_result import TerminalNodeSearchResultsResult
from .terminal_node_string_result import TerminalNodeStringResult
from .test_case_chat_history_variable_value import TestCaseChatHistoryVariableValue
from .test_case_error_variable_value import TestCaseErrorVariableValue
from .test_case_function_call_variable_value import TestCaseFunctionCallVariableValue
from .test_case_json_variable_value import TestCaseJsonVariableValue
from .test_case_number_variable_value import TestCaseNumberVariableValue
from .test_case_search_results_variable_value import TestCaseSearchResultsVariableValue
from .test_case_string_variable_value import TestCaseStringVariableValue
from .test_case_variable_value import (
    TestCaseVariableValue,
    TestCaseVariableValue_ChatHistory,
    TestCaseVariableValue_Error,
    TestCaseVariableValue_FunctionCall,
    TestCaseVariableValue_Json,
    TestCaseVariableValue_Number,
    TestCaseVariableValue_SearchResults,
    TestCaseVariableValue_String,
)
from .test_suite_run_deployment_release_tag_exec_config import TestSuiteRunDeploymentReleaseTagExecConfig
from .test_suite_run_deployment_release_tag_exec_config_data import TestSuiteRunDeploymentReleaseTagExecConfigData
from .test_suite_run_deployment_release_tag_exec_config_data_request import (
    TestSuiteRunDeploymentReleaseTagExecConfigDataRequest,
)
from .test_suite_run_deployment_release_tag_exec_config_request import TestSuiteRunDeploymentReleaseTagExecConfigRequest
from .test_suite_run_deployment_release_tag_exec_config_type_enum import (
    TestSuiteRunDeploymentReleaseTagExecConfigTypeEnum,
)
from .test_suite_run_exec_config import (
    TestSuiteRunExecConfig,
    TestSuiteRunExecConfig_DeploymentReleaseTag,
    TestSuiteRunExecConfig_External,
    TestSuiteRunExecConfig_WorkflowReleaseTag,
)
from .test_suite_run_exec_config_request import (
    TestSuiteRunExecConfigRequest,
    TestSuiteRunExecConfigRequest_DeploymentReleaseTag,
    TestSuiteRunExecConfigRequest_External,
    TestSuiteRunExecConfigRequest_WorkflowReleaseTag,
)
from .test_suite_run_execution import TestSuiteRunExecution
from .test_suite_run_execution_chat_history_output import TestSuiteRunExecutionChatHistoryOutput
from .test_suite_run_execution_error_output import TestSuiteRunExecutionErrorOutput
from .test_suite_run_execution_function_call_output import TestSuiteRunExecutionFunctionCallOutput
from .test_suite_run_execution_json_output import TestSuiteRunExecutionJsonOutput
from .test_suite_run_execution_metric_definition import TestSuiteRunExecutionMetricDefinition
from .test_suite_run_execution_metric_result import TestSuiteRunExecutionMetricResult
from .test_suite_run_execution_number_output import TestSuiteRunExecutionNumberOutput
from .test_suite_run_execution_output import (
    TestSuiteRunExecutionOutput,
    TestSuiteRunExecutionOutput_ChatHistory,
    TestSuiteRunExecutionOutput_Error,
    TestSuiteRunExecutionOutput_FunctionCall,
    TestSuiteRunExecutionOutput_Json,
    TestSuiteRunExecutionOutput_Number,
    TestSuiteRunExecutionOutput_SearchResults,
    TestSuiteRunExecutionOutput_String,
)
from .test_suite_run_execution_search_results_output import TestSuiteRunExecutionSearchResultsOutput
from .test_suite_run_execution_string_output import TestSuiteRunExecutionStringOutput
from .test_suite_run_external_exec_config import TestSuiteRunExternalExecConfig
from .test_suite_run_external_exec_config_data import TestSuiteRunExternalExecConfigData
from .test_suite_run_external_exec_config_data_request import TestSuiteRunExternalExecConfigDataRequest
from .test_suite_run_external_exec_config_request import TestSuiteRunExternalExecConfigRequest
from .test_suite_run_external_exec_config_type_enum import TestSuiteRunExternalExecConfigTypeEnum
from .test_suite_run_metric_error_output import TestSuiteRunMetricErrorOutput
from .test_suite_run_metric_error_output_type_enum import TestSuiteRunMetricErrorOutputTypeEnum
from .test_suite_run_metric_number_output import TestSuiteRunMetricNumberOutput
from .test_suite_run_metric_number_output_type_enum import TestSuiteRunMetricNumberOutputTypeEnum
from .test_suite_run_metric_output import (
    TestSuiteRunMetricOutput,
    TestSuiteRunMetricOutput_Error,
    TestSuiteRunMetricOutput_Number,
    TestSuiteRunMetricOutput_String,
)
from .test_suite_run_metric_string_output import TestSuiteRunMetricStringOutput
from .test_suite_run_metric_string_output_type_enum import TestSuiteRunMetricStringOutputTypeEnum
from .test_suite_run_read import TestSuiteRunRead
from .test_suite_run_state import TestSuiteRunState
from .test_suite_run_test_suite import TestSuiteRunTestSuite
from .test_suite_run_workflow_release_tag_exec_config import TestSuiteRunWorkflowReleaseTagExecConfig
from .test_suite_run_workflow_release_tag_exec_config_data import TestSuiteRunWorkflowReleaseTagExecConfigData
from .test_suite_run_workflow_release_tag_exec_config_data_request import (
    TestSuiteRunWorkflowReleaseTagExecConfigDataRequest,
)
from .test_suite_run_workflow_release_tag_exec_config_request import TestSuiteRunWorkflowReleaseTagExecConfigRequest
from .test_suite_run_workflow_release_tag_exec_config_type_enum import TestSuiteRunWorkflowReleaseTagExecConfigTypeEnum
from .test_suite_test_case import TestSuiteTestCase
from .upload_document_error_response import UploadDocumentErrorResponse
from .upload_document_response import UploadDocumentResponse
from .vellum_error import VellumError
from .vellum_error_code_enum import VellumErrorCodeEnum
from .vellum_error_request import VellumErrorRequest
from .vellum_image import VellumImage
from .vellum_image_request import VellumImageRequest
from .vellum_variable import VellumVariable
from .vellum_variable_type import VellumVariableType
from .workflow_deployment_read import WorkflowDeploymentRead
from .workflow_event_error import WorkflowEventError
from .workflow_execution_actual_chat_history_request import WorkflowExecutionActualChatHistoryRequest
from .workflow_execution_actual_json_request import WorkflowExecutionActualJsonRequest
from .workflow_execution_actual_string_request import WorkflowExecutionActualStringRequest
from .workflow_execution_event_error_code import WorkflowExecutionEventErrorCode
from .workflow_execution_event_type import WorkflowExecutionEventType
from .workflow_execution_node_result_event import WorkflowExecutionNodeResultEvent
from .workflow_execution_workflow_result_event import WorkflowExecutionWorkflowResultEvent
from .workflow_node_result_data import (
    WorkflowNodeResultData,
    WorkflowNodeResultData_Api,
    WorkflowNodeResultData_CodeExecution,
    WorkflowNodeResultData_Conditional,
    WorkflowNodeResultData_Prompt,
    WorkflowNodeResultData_Search,
    WorkflowNodeResultData_Subworkflow,
    WorkflowNodeResultData_Templating,
    WorkflowNodeResultData_Terminal,
)
from .workflow_node_result_event import (
    WorkflowNodeResultEvent,
    WorkflowNodeResultEvent_Fulfilled,
    WorkflowNodeResultEvent_Initiated,
    WorkflowNodeResultEvent_Rejected,
    WorkflowNodeResultEvent_Streaming,
)
from .workflow_node_result_event_state import WorkflowNodeResultEventState
from .workflow_output import (
    WorkflowOutput,
    WorkflowOutput_Array,
    WorkflowOutput_ChatHistory,
    WorkflowOutput_Error,
    WorkflowOutput_FunctionCall,
    WorkflowOutput_Image,
    WorkflowOutput_Json,
    WorkflowOutput_Number,
    WorkflowOutput_SearchResults,
    WorkflowOutput_String,
)
from .workflow_output_array import WorkflowOutputArray
from .workflow_output_chat_history import WorkflowOutputChatHistory
from .workflow_output_error import WorkflowOutputError
from .workflow_output_function_call import WorkflowOutputFunctionCall
from .workflow_output_image import WorkflowOutputImage
from .workflow_output_json import WorkflowOutputJson
from .workflow_output_number import WorkflowOutputNumber
from .workflow_output_search_results import WorkflowOutputSearchResults
from .workflow_output_string import WorkflowOutputString
from .workflow_request_chat_history_input_request import WorkflowRequestChatHistoryInputRequest
from .workflow_request_input_request import (
    WorkflowRequestInputRequest,
    WorkflowRequestInputRequest_ChatHistory,
    WorkflowRequestInputRequest_Json,
    WorkflowRequestInputRequest_Number,
    WorkflowRequestInputRequest_String,
)
from .workflow_request_json_input_request import WorkflowRequestJsonInputRequest
from .workflow_request_number_input_request import WorkflowRequestNumberInputRequest
from .workflow_request_string_input_request import WorkflowRequestStringInputRequest
from .workflow_result_event import WorkflowResultEvent
from .workflow_result_event_output_data import (
    WorkflowResultEventOutputData,
    WorkflowResultEventOutputData_Array,
    WorkflowResultEventOutputData_ChatHistory,
    WorkflowResultEventOutputData_Error,
    WorkflowResultEventOutputData_FunctionCall,
    WorkflowResultEventOutputData_Json,
    WorkflowResultEventOutputData_Number,
    WorkflowResultEventOutputData_SearchResults,
    WorkflowResultEventOutputData_String,
)
from .workflow_result_event_output_data_array import WorkflowResultEventOutputDataArray
from .workflow_result_event_output_data_chat_history import WorkflowResultEventOutputDataChatHistory
from .workflow_result_event_output_data_error import WorkflowResultEventOutputDataError
from .workflow_result_event_output_data_function_call import WorkflowResultEventOutputDataFunctionCall
from .workflow_result_event_output_data_json import WorkflowResultEventOutputDataJson
from .workflow_result_event_output_data_number import WorkflowResultEventOutputDataNumber
from .workflow_result_event_output_data_search_results import WorkflowResultEventOutputDataSearchResults
from .workflow_result_event_output_data_string import WorkflowResultEventOutputDataString
from .workflow_stream_event import WorkflowStreamEvent, WorkflowStreamEvent_Node, WorkflowStreamEvent_Workflow

__all__ = [
    "ApiNodeResult",
    "ApiNodeResultData",
    "ArrayChatMessageContent",
    "ArrayChatMessageContentItem",
    "ArrayChatMessageContentItemRequest",
    "ArrayChatMessageContentItemRequest_FunctionCall",
    "ArrayChatMessageContentItemRequest_Image",
    "ArrayChatMessageContentItemRequest_String",
    "ArrayChatMessageContentItem_FunctionCall",
    "ArrayChatMessageContentItem_Image",
    "ArrayChatMessageContentItem_String",
    "ArrayChatMessageContentRequest",
    "ArrayEnum",
    "ArrayVariableValueItem",
    "ArrayVariableValueItem_ChatHistory",
    "ArrayVariableValueItem_Error",
    "ArrayVariableValueItem_FunctionCall",
    "ArrayVariableValueItem_Image",
    "ArrayVariableValueItem_Json",
    "ArrayVariableValueItem_Number",
    "ArrayVariableValueItem_SearchResults",
    "ArrayVariableValueItem_String",
    "ChatHistoryEnum",
    "ChatHistoryInputRequest",
    "ChatHistoryVariableValue",
    "ChatMessage",
    "ChatMessageContent",
    "ChatMessageContentRequest",
    "ChatMessageContentRequest_Array",
    "ChatMessageContentRequest_FunctionCall",
    "ChatMessageContentRequest_Image",
    "ChatMessageContentRequest_String",
    "ChatMessageContent_Array",
    "ChatMessageContent_FunctionCall",
    "ChatMessageContent_Image",
    "ChatMessageContent_String",
    "ChatMessageRequest",
    "ChatMessageRole",
    "CodeExecutionNodeArrayResult",
    "CodeExecutionNodeChatHistoryResult",
    "CodeExecutionNodeErrorResult",
    "CodeExecutionNodeFunctionCallResult",
    "CodeExecutionNodeJsonResult",
    "CodeExecutionNodeNumberResult",
    "CodeExecutionNodeResult",
    "CodeExecutionNodeResultData",
    "CodeExecutionNodeResultOutput",
    "CodeExecutionNodeResultOutput_Array",
    "CodeExecutionNodeResultOutput_ChatHistory",
    "CodeExecutionNodeResultOutput_Error",
    "CodeExecutionNodeResultOutput_FunctionCall",
    "CodeExecutionNodeResultOutput_Json",
    "CodeExecutionNodeResultOutput_Number",
    "CodeExecutionNodeResultOutput_SearchResults",
    "CodeExecutionNodeResultOutput_String",
    "CodeExecutionNodeSearchResultsResult",
    "CodeExecutionNodeStringResult",
    "ConditionalNodeResult",
    "ConditionalNodeResultData",
    "DeploymentProviderPayloadResponse",
    "DeploymentRead",
    "DocumentDocumentToDocumentIndex",
    "DocumentIndexRead",
    "DocumentRead",
    "DocumentStatus",
    "EnrichedNormalizedCompletion",
    "EntityStatus",
    "EnvironmentEnum",
    "ErrorEnum",
    "ErrorVariableValue",
    "ErrorVellumValue",
    "ExecutePromptApiErrorResponse",
    "ExecutePromptEvent",
    "ExecutePromptEvent_Fulfilled",
    "ExecutePromptEvent_Initiated",
    "ExecutePromptEvent_Rejected",
    "ExecutePromptEvent_Streaming",
    "ExecutePromptResponse",
    "ExecutePromptResponse_Fulfilled",
    "ExecutePromptResponse_Rejected",
    "ExecuteWorkflowErrorResponse",
    "ExecuteWorkflowResponse",
    "ExecuteWorkflowStreamErrorResponse",
    "ExecuteWorkflowWorkflowResultEvent",
    "ExecuteWorkflowWorkflowResultEvent_Fulfilled",
    "ExecuteWorkflowWorkflowResultEvent_Rejected",
    "ExecutionArrayVellumValue",
    "ExecutionChatHistoryVellumValue",
    "ExecutionErrorVellumValue",
    "ExecutionFunctionCallVellumValue",
    "ExecutionJsonVellumValue",
    "ExecutionNumberVellumValue",
    "ExecutionSearchResultsVellumValue",
    "ExecutionStringVellumValue",
    "ExecutionVellumValue",
    "ExecutionVellumValue_Array",
    "ExecutionVellumValue_ChatHistory",
    "ExecutionVellumValue_Error",
    "ExecutionVellumValue_FunctionCall",
    "ExecutionVellumValue_Json",
    "ExecutionVellumValue_Number",
    "ExecutionVellumValue_SearchResults",
    "ExecutionVellumValue_String",
    "ExternalTestCaseExecution",
    "ExternalTestCaseExecutionRequest",
    "FinishReasonEnum",
    "FulfilledEnum",
    "FulfilledExecutePromptEvent",
    "FulfilledExecutePromptResponse",
    "FulfilledExecuteWorkflowWorkflowResultEvent",
    "FulfilledFunctionCall",
    "FulfilledFunctionCallRequest",
    "FulfilledPromptExecutionMeta",
    "FulfilledWorkflowNodeResultEvent",
    "FunctionCall",
    "FunctionCallChatMessageContent",
    "FunctionCallChatMessageContentRequest",
    "FunctionCallChatMessageContentValue",
    "FunctionCallChatMessageContentValueRequest",
    "FunctionCallEnum",
    "FunctionCallVariableValue",
    "FunctionCallVellumValue",
    "FunctionCall_Fulfilled",
    "FunctionCall_Rejected",
    "GenerateErrorResponse",
    "GenerateOptionsRequest",
    "GenerateRequest",
    "GenerateResponse",
    "GenerateResult",
    "GenerateResultData",
    "GenerateResultError",
    "GenerateStreamResponse",
    "GenerateStreamResult",
    "GenerateStreamResultData",
    "ImageChatMessageContent",
    "ImageChatMessageContentRequest",
    "ImageEnum",
    "ImageVariableValue",
    "IndexingStateEnum",
    "InitiatedEnum",
    "InitiatedExecutePromptEvent",
    "InitiatedPromptExecutionMeta",
    "InitiatedWorkflowNodeResultEvent",
    "JsonEnum",
    "JsonInputRequest",
    "JsonVariableValue",
    "JsonVellumValue",
    "LogicalOperator",
    "LogprobsEnum",
    "MetadataFilterConfigRequest",
    "MetadataFilterRuleCombinator",
    "MetadataFilterRuleRequest",
    "MlModelUsage",
    "NamedScenarioInputChatHistoryVariableValueRequest",
    "NamedScenarioInputRequest",
    "NamedScenarioInputRequest_ChatHistory",
    "NamedScenarioInputRequest_String",
    "NamedScenarioInputStringVariableValueRequest",
    "NamedTestCaseChatHistoryVariableValue",
    "NamedTestCaseChatHistoryVariableValueRequest",
    "NamedTestCaseErrorVariableValue",
    "NamedTestCaseErrorVariableValueRequest",
    "NamedTestCaseFunctionCallVariableValue",
    "NamedTestCaseFunctionCallVariableValueRequest",
    "NamedTestCaseJsonVariableValue",
    "NamedTestCaseJsonVariableValueRequest",
    "NamedTestCaseNumberVariableValue",
    "NamedTestCaseNumberVariableValueRequest",
    "NamedTestCaseSearchResultsVariableValue",
    "NamedTestCaseSearchResultsVariableValueRequest",
    "NamedTestCaseStringVariableValue",
    "NamedTestCaseStringVariableValueRequest",
    "NamedTestCaseVariableValue",
    "NamedTestCaseVariableValueRequest",
    "NamedTestCaseVariableValueRequest_ChatHistory",
    "NamedTestCaseVariableValueRequest_Error",
    "NamedTestCaseVariableValueRequest_FunctionCall",
    "NamedTestCaseVariableValueRequest_Json",
    "NamedTestCaseVariableValueRequest_Number",
    "NamedTestCaseVariableValueRequest_SearchResults",
    "NamedTestCaseVariableValueRequest_String",
    "NamedTestCaseVariableValue_ChatHistory",
    "NamedTestCaseVariableValue_Error",
    "NamedTestCaseVariableValue_FunctionCall",
    "NamedTestCaseVariableValue_Json",
    "NamedTestCaseVariableValue_Number",
    "NamedTestCaseVariableValue_SearchResults",
    "NamedTestCaseVariableValue_String",
    "NodeInputCompiledArrayValue",
    "NodeInputCompiledChatHistoryValue",
    "NodeInputCompiledErrorValue",
    "NodeInputCompiledFunctionCall",
    "NodeInputCompiledJsonValue",
    "NodeInputCompiledNumberValue",
    "NodeInputCompiledSearchResultsValue",
    "NodeInputCompiledStringValue",
    "NodeInputVariableCompiledValue",
    "NodeInputVariableCompiledValue_Array",
    "NodeInputVariableCompiledValue_ChatHistory",
    "NodeInputVariableCompiledValue_Error",
    "NodeInputVariableCompiledValue_FunctionCall",
    "NodeInputVariableCompiledValue_Json",
    "NodeInputVariableCompiledValue_Number",
    "NodeInputVariableCompiledValue_SearchResults",
    "NodeInputVariableCompiledValue_String",
    "NodeOutputCompiledArrayValue",
    "NodeOutputCompiledChatHistoryValue",
    "NodeOutputCompiledErrorValue",
    "NodeOutputCompiledFunctionCallValue",
    "NodeOutputCompiledJsonValue",
    "NodeOutputCompiledNumberValue",
    "NodeOutputCompiledSearchResultsValue",
    "NodeOutputCompiledStringValue",
    "NodeOutputCompiledValue",
    "NodeOutputCompiledValue_Array",
    "NodeOutputCompiledValue_ChatHistory",
    "NodeOutputCompiledValue_Error",
    "NodeOutputCompiledValue_FunctionCall",
    "NodeOutputCompiledValue_Json",
    "NodeOutputCompiledValue_Number",
    "NodeOutputCompiledValue_SearchResults",
    "NodeOutputCompiledValue_String",
    "NormalizedLogProbs",
    "NormalizedTokenLogProbs",
    "NumberEnum",
    "NumberVariableValue",
    "PaginatedDocumentIndexReadList",
    "PaginatedSlimDeploymentReadList",
    "PaginatedSlimDocumentList",
    "PaginatedSlimWorkflowDeploymentList",
    "PaginatedTestSuiteRunExecutionList",
    "PaginatedTestSuiteTestCaseList",
    "ProcessingFailureReasonEnum",
    "ProcessingStateEnum",
    "PromptDeploymentExpandMetaRequestRequest",
    "PromptDeploymentInputRequest",
    "PromptDeploymentInputRequest_ChatHistory",
    "PromptDeploymentInputRequest_Json",
    "PromptDeploymentInputRequest_String",
    "PromptExecutionMeta",
    "PromptNodeResult",
    "PromptNodeResultData",
    "PromptOutput",
    "PromptOutput_Error",
    "PromptOutput_FunctionCall",
    "PromptOutput_Json",
    "PromptOutput_String",
    "RawPromptExecutionOverridesRequest",
    "RejectedEnum",
    "RejectedExecutePromptEvent",
    "RejectedExecutePromptResponse",
    "RejectedExecuteWorkflowWorkflowResultEvent",
    "RejectedFunctionCall",
    "RejectedPromptExecutionMeta",
    "RejectedWorkflowNodeResultEvent",
    "SandboxScenario",
    "ScenarioInput",
    "ScenarioInputChatHistoryVariableValue",
    "ScenarioInputStringVariableValue",
    "ScenarioInput_ChatHistory",
    "ScenarioInput_String",
    "SearchErrorResponse",
    "SearchFiltersRequest",
    "SearchNodeResult",
    "SearchNodeResultData",
    "SearchRequestOptionsRequest",
    "SearchResponse",
    "SearchResult",
    "SearchResultDocument",
    "SearchResultDocumentRequest",
    "SearchResultMergingRequest",
    "SearchResultRequest",
    "SearchResultsEnum",
    "SearchResultsVariableValue",
    "SearchWeightsRequest",
    "SlimDeploymentRead",
    "SlimDocument",
    "SlimWorkflowDeployment",
    "StreamingEnum",
    "StreamingExecutePromptEvent",
    "StreamingPromptExecutionMeta",
    "StreamingWorkflowNodeResultEvent",
    "StringChatMessageContent",
    "StringChatMessageContentRequest",
    "StringEnum",
    "StringInputRequest",
    "StringVariableValue",
    "StringVellumValue",
    "SubmitCompletionActualRequest",
    "SubmitCompletionActualsErrorResponse",
    "SubmitWorkflowExecutionActualRequest",
    "SubmitWorkflowExecutionActualRequest_ChatHistory",
    "SubmitWorkflowExecutionActualRequest_Json",
    "SubmitWorkflowExecutionActualRequest_String",
    "SubworkflowEnum",
    "SubworkflowNodeResult",
    "TemplatingNodeArrayResult",
    "TemplatingNodeChatHistoryResult",
    "TemplatingNodeErrorResult",
    "TemplatingNodeFunctionCallResult",
    "TemplatingNodeJsonResult",
    "TemplatingNodeNumberResult",
    "TemplatingNodeResult",
    "TemplatingNodeResultData",
    "TemplatingNodeResultOutput",
    "TemplatingNodeResultOutput_Array",
    "TemplatingNodeResultOutput_ChatHistory",
    "TemplatingNodeResultOutput_Error",
    "TemplatingNodeResultOutput_FunctionCall",
    "TemplatingNodeResultOutput_Json",
    "TemplatingNodeResultOutput_Number",
    "TemplatingNodeResultOutput_SearchResults",
    "TemplatingNodeResultOutput_String",
    "TemplatingNodeSearchResultsResult",
    "TemplatingNodeStringResult",
    "TerminalNodeArrayResult",
    "TerminalNodeChatHistoryResult",
    "TerminalNodeErrorResult",
    "TerminalNodeFunctionCallResult",
    "TerminalNodeJsonResult",
    "TerminalNodeNumberResult",
    "TerminalNodeResult",
    "TerminalNodeResultData",
    "TerminalNodeResultOutput",
    "TerminalNodeResultOutput_Array",
    "TerminalNodeResultOutput_ChatHistory",
    "TerminalNodeResultOutput_Error",
    "TerminalNodeResultOutput_FunctionCall",
    "TerminalNodeResultOutput_Json",
    "TerminalNodeResultOutput_Number",
    "TerminalNodeResultOutput_SearchResults",
    "TerminalNodeResultOutput_String",
    "TerminalNodeSearchResultsResult",
    "TerminalNodeStringResult",
    "TestCaseChatHistoryVariableValue",
    "TestCaseErrorVariableValue",
    "TestCaseFunctionCallVariableValue",
    "TestCaseJsonVariableValue",
    "TestCaseNumberVariableValue",
    "TestCaseSearchResultsVariableValue",
    "TestCaseStringVariableValue",
    "TestCaseVariableValue",
    "TestCaseVariableValue_ChatHistory",
    "TestCaseVariableValue_Error",
    "TestCaseVariableValue_FunctionCall",
    "TestCaseVariableValue_Json",
    "TestCaseVariableValue_Number",
    "TestCaseVariableValue_SearchResults",
    "TestCaseVariableValue_String",
    "TestSuiteRunDeploymentReleaseTagExecConfig",
    "TestSuiteRunDeploymentReleaseTagExecConfigData",
    "TestSuiteRunDeploymentReleaseTagExecConfigDataRequest",
    "TestSuiteRunDeploymentReleaseTagExecConfigRequest",
    "TestSuiteRunDeploymentReleaseTagExecConfigTypeEnum",
    "TestSuiteRunExecConfig",
    "TestSuiteRunExecConfigRequest",
    "TestSuiteRunExecConfigRequest_DeploymentReleaseTag",
    "TestSuiteRunExecConfigRequest_External",
    "TestSuiteRunExecConfigRequest_WorkflowReleaseTag",
    "TestSuiteRunExecConfig_DeploymentReleaseTag",
    "TestSuiteRunExecConfig_External",
    "TestSuiteRunExecConfig_WorkflowReleaseTag",
    "TestSuiteRunExecution",
    "TestSuiteRunExecutionChatHistoryOutput",
    "TestSuiteRunExecutionErrorOutput",
    "TestSuiteRunExecutionFunctionCallOutput",
    "TestSuiteRunExecutionJsonOutput",
    "TestSuiteRunExecutionMetricDefinition",
    "TestSuiteRunExecutionMetricResult",
    "TestSuiteRunExecutionNumberOutput",
    "TestSuiteRunExecutionOutput",
    "TestSuiteRunExecutionOutput_ChatHistory",
    "TestSuiteRunExecutionOutput_Error",
    "TestSuiteRunExecutionOutput_FunctionCall",
    "TestSuiteRunExecutionOutput_Json",
    "TestSuiteRunExecutionOutput_Number",
    "TestSuiteRunExecutionOutput_SearchResults",
    "TestSuiteRunExecutionOutput_String",
    "TestSuiteRunExecutionSearchResultsOutput",
    "TestSuiteRunExecutionStringOutput",
    "TestSuiteRunExternalExecConfig",
    "TestSuiteRunExternalExecConfigData",
    "TestSuiteRunExternalExecConfigDataRequest",
    "TestSuiteRunExternalExecConfigRequest",
    "TestSuiteRunExternalExecConfigTypeEnum",
    "TestSuiteRunMetricErrorOutput",
    "TestSuiteRunMetricErrorOutputTypeEnum",
    "TestSuiteRunMetricNumberOutput",
    "TestSuiteRunMetricNumberOutputTypeEnum",
    "TestSuiteRunMetricOutput",
    "TestSuiteRunMetricOutput_Error",
    "TestSuiteRunMetricOutput_Number",
    "TestSuiteRunMetricOutput_String",
    "TestSuiteRunMetricStringOutput",
    "TestSuiteRunMetricStringOutputTypeEnum",
    "TestSuiteRunRead",
    "TestSuiteRunState",
    "TestSuiteRunTestSuite",
    "TestSuiteRunWorkflowReleaseTagExecConfig",
    "TestSuiteRunWorkflowReleaseTagExecConfigData",
    "TestSuiteRunWorkflowReleaseTagExecConfigDataRequest",
    "TestSuiteRunWorkflowReleaseTagExecConfigRequest",
    "TestSuiteRunWorkflowReleaseTagExecConfigTypeEnum",
    "TestSuiteTestCase",
    "UploadDocumentErrorResponse",
    "UploadDocumentResponse",
    "VellumError",
    "VellumErrorCodeEnum",
    "VellumErrorRequest",
    "VellumImage",
    "VellumImageRequest",
    "VellumVariable",
    "VellumVariableType",
    "WorkflowDeploymentRead",
    "WorkflowEventError",
    "WorkflowExecutionActualChatHistoryRequest",
    "WorkflowExecutionActualJsonRequest",
    "WorkflowExecutionActualStringRequest",
    "WorkflowExecutionEventErrorCode",
    "WorkflowExecutionEventType",
    "WorkflowExecutionNodeResultEvent",
    "WorkflowExecutionWorkflowResultEvent",
    "WorkflowNodeResultData",
    "WorkflowNodeResultData_Api",
    "WorkflowNodeResultData_CodeExecution",
    "WorkflowNodeResultData_Conditional",
    "WorkflowNodeResultData_Prompt",
    "WorkflowNodeResultData_Search",
    "WorkflowNodeResultData_Subworkflow",
    "WorkflowNodeResultData_Templating",
    "WorkflowNodeResultData_Terminal",
    "WorkflowNodeResultEvent",
    "WorkflowNodeResultEventState",
    "WorkflowNodeResultEvent_Fulfilled",
    "WorkflowNodeResultEvent_Initiated",
    "WorkflowNodeResultEvent_Rejected",
    "WorkflowNodeResultEvent_Streaming",
    "WorkflowOutput",
    "WorkflowOutputArray",
    "WorkflowOutputChatHistory",
    "WorkflowOutputError",
    "WorkflowOutputFunctionCall",
    "WorkflowOutputImage",
    "WorkflowOutputJson",
    "WorkflowOutputNumber",
    "WorkflowOutputSearchResults",
    "WorkflowOutputString",
    "WorkflowOutput_Array",
    "WorkflowOutput_ChatHistory",
    "WorkflowOutput_Error",
    "WorkflowOutput_FunctionCall",
    "WorkflowOutput_Image",
    "WorkflowOutput_Json",
    "WorkflowOutput_Number",
    "WorkflowOutput_SearchResults",
    "WorkflowOutput_String",
    "WorkflowRequestChatHistoryInputRequest",
    "WorkflowRequestInputRequest",
    "WorkflowRequestInputRequest_ChatHistory",
    "WorkflowRequestInputRequest_Json",
    "WorkflowRequestInputRequest_Number",
    "WorkflowRequestInputRequest_String",
    "WorkflowRequestJsonInputRequest",
    "WorkflowRequestNumberInputRequest",
    "WorkflowRequestStringInputRequest",
    "WorkflowResultEvent",
    "WorkflowResultEventOutputData",
    "WorkflowResultEventOutputDataArray",
    "WorkflowResultEventOutputDataChatHistory",
    "WorkflowResultEventOutputDataError",
    "WorkflowResultEventOutputDataFunctionCall",
    "WorkflowResultEventOutputDataJson",
    "WorkflowResultEventOutputDataNumber",
    "WorkflowResultEventOutputDataSearchResults",
    "WorkflowResultEventOutputDataString",
    "WorkflowResultEventOutputData_Array",
    "WorkflowResultEventOutputData_ChatHistory",
    "WorkflowResultEventOutputData_Error",
    "WorkflowResultEventOutputData_FunctionCall",
    "WorkflowResultEventOutputData_Json",
    "WorkflowResultEventOutputData_Number",
    "WorkflowResultEventOutputData_SearchResults",
    "WorkflowResultEventOutputData_String",
    "WorkflowStreamEvent",
    "WorkflowStreamEvent_Node",
    "WorkflowStreamEvent_Workflow",
]
